@@ -1,7 +1,7 @@
 /* BFD back-end for raw ARM a.out binaries.
-   Copyright (C) 1994, 1995, 1996, 1997, 1998 Free Software Foundation, Inc.
+   Copyright (C) 1994, 95, 96, 97, 98, 1999 Free Software Foundation, Inc.
    Contributed by Richard Earnshaw (rwe@pegasus.esprit.ec.org)
-   
+
 This file is part of BFD, the Binary File Descriptor library.
 
 This program is free software; you can redistribute it and/or modify
@@ -18,7 +18,6 @@ You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
-
 #define N_TXTADDR(x) \
   ((N_MAGIC(x) == NMAGIC) ? 0x8000 : \
    (N_MAGIC(x) != ZMAGIC) ? 0 : \
@@ -44,7 +43,7 @@ reloc_howto_type 	*MYARM(bfd_reloc_type_lookup)
 				PARAMS((bfd *, bfd_reloc_code_real_type));
 static boolean 		MYARM(write_object_contents)	PARAMS((bfd *));
 
-/* Avoid multiple defininitions from aoutx if supporting standarad a.out 
+/* Avoid multiple defininitions from aoutx if supporting standarad a.out
    as well as our own.  */
 #define NAME(x,y) CAT3(aoutarm,_32_,y)
 
@@ -63,7 +62,7 @@ MY(fix_pcrel_26)	 PARAMS ((bfd *, arelent *, asymbol *, PTR,
 static void MY(swap_std_reloc_in) PARAMS ((bfd *, struct reloc_std_external *,
 					   arelent *, asymbol **,
 					   bfd_size_type));
-void MY(swap_std_reloc_out) PARAMS ((bfd *, arelent *, 
+void MY(swap_std_reloc_out) PARAMS ((bfd *, arelent *,
 				     struct reloc_std_external *));
 
 reloc_howto_type MY(howto_table)[] =
@@ -87,48 +86,18 @@ reloc_howto_type MY(howto_table)[] =
   HOWTO (7, 2, 2, 26, false, 0, complain_overflow_signed,
 	 MY(fix_pcrel_26_done), "ARM26D", true, 0x0, 0x0,
 	 false),
-  {-1},
+  EMPTY_HOWTO (-1),
   HOWTO (9, 0, -1, 16, false, 0, complain_overflow_bitfield, 0, "NEG16", true,
 	 0x0000ffff, 0x0000ffff, false),
   HOWTO (10, 0, -2, 32, false, 0, complain_overflow_bitfield, 0, "NEG32", true,
-	 0xffffffff, 0xffffffff, false),
-  {-1},
-  {-1},
-  {-1},
-  {-1},
-  {-1},
-
-  {-1},
-  HOWTO (17, 0, 1, 16, false, 0, complain_overflow_bitfield, 0, "GOT12", true,
-	 0x00000fff, 0x00000fff, false),
-  HOWTO (18, 0, 2, 32, false, 0, complain_overflow_bitfield, 0, "GOT32", true,
-	 0xffffffff, 0xffffffff, false),
-  HOWTO (19, 0, 2, 26, true, 0, complain_overflow_bitfield, MY(fix_pcrel_26), 
-	 "JMPSLOT", true, 0x00ffffff, 0x00ffffff, true),
-
-  {-1},
-  {-1},
-  HOWTO (22, 0, 2, 32, true, 0, complain_overflow_bitfield, 0, "GOTPC", true,
-	 0xffffffff, 0xffffffff, true),
-  {-1},
-
-  {-1},
-  {-1},
-  {-1},
-  {-1},
-  {-1},
-  {-1},
-  {-1},
-  {-1},
+	 0xffffffff, 0xffffffff, false)
 };
 
 #define RELOC_ARM_BITS_NEG_BIG      ((unsigned int) 0x08)
 #define RELOC_ARM_BITS_NEG_LITTLE   ((unsigned int) 0x10)
-#define RELOC_ARM_BITS_PIC_BIG      ((unsigned int) 0x04)
-#define RELOC_ARM_BITS_PIC_LITTLE   ((unsigned int) 0x20)
 
 reloc_howto_type *
-MY(reloc_howto)(abfd, rel, r_index, r_extern, r_pcrel)
+MY(reloc_howto) (abfd, rel, r_index, r_extern, r_pcrel)
      bfd *abfd;
      struct reloc_std_external *rel;
      int *r_index;
@@ -138,7 +107,6 @@ MY(reloc_howto)(abfd, rel, r_index, r_extern, r_pcrel)
   unsigned int r_length;
   unsigned int r_pcrel_done;
   unsigned int r_neg;
-  unsigned int r_pic;
   int index;
 
   *r_pcrel = 0;
@@ -150,7 +118,6 @@ MY(reloc_howto)(abfd, rel, r_index, r_extern, r_pcrel)
       *r_extern    = (0 != (rel->r_type[0] & RELOC_STD_BITS_EXTERN_BIG));
       r_pcrel_done = (0 != (rel->r_type[0] & RELOC_STD_BITS_PCREL_BIG));
       r_neg 	   = (0 != (rel->r_type[0] & RELOC_ARM_BITS_NEG_BIG));
-      r_pic 	   = (0 != (rel->r_type[0] & RELOC_ARM_BITS_PIC_BIG));
       r_length     = ((rel->r_type[0] & RELOC_STD_BITS_LENGTH_BIG)
 		      >> RELOC_STD_BITS_LENGTH_SH_BIG);
     }
@@ -162,22 +129,21 @@ MY(reloc_howto)(abfd, rel, r_index, r_extern, r_pcrel)
       *r_extern    = (0 != (rel->r_type[0] & RELOC_STD_BITS_EXTERN_LITTLE));
       r_pcrel_done = (0 != (rel->r_type[0] & RELOC_STD_BITS_PCREL_LITTLE));
       r_neg 	   = (0 != (rel->r_type[0] & RELOC_ARM_BITS_NEG_LITTLE));
-      r_pic 	   = (0 != (rel->r_type[0] & RELOC_ARM_BITS_PIC_LITTLE));
       r_length     = ((rel->r_type[0] & RELOC_STD_BITS_LENGTH_LITTLE)
 		      >> RELOC_STD_BITS_LENGTH_SH_LITTLE);
     }
-  index = r_length + 4 * r_pcrel_done + 8 * r_neg + 16 * r_pic;
-  if (index == 3 || index == 19)
+  index = r_length + 4 * r_pcrel_done + 8 * r_neg;
+  if (index == 3)
     *r_pcrel = 1;
 
   return MY(howto_table) + index;
 }
- 
+
 #define MY_reloc_howto(BFD, REL, IN, EX, PC) \
 	MY(reloc_howto) (BFD, REL, &IN, &EX, &PC)
 
 void
-MY(put_reloc)(abfd, r_extern, r_index, value, howto, reloc)
+MY(put_reloc) (abfd, r_extern, r_index, value, howto, reloc)
      bfd *abfd;
      int r_extern;
      int r_index;
@@ -188,18 +154,16 @@ MY(put_reloc)(abfd, r_extern, r_index, value, howto, reloc)
   unsigned int r_length;
   int r_pcrel;
   int r_neg;
-  int r_pic;
 
   PUT_WORD (abfd, value, reloc->r_address);
   r_length = howto->size ;	/* Size as a power of two */
 
-  /* Special case for branch relocations. */
+  /* Special case for branch relocations.  */
   if (howto->type == 3 || howto->type == 7)
     r_length = 3;
 
   r_pcrel  = howto->type & 4; 	/* PC Relative done? */
   r_neg = howto->type & 8;	/* Negative relocation */
-  r_pic = howto->type & 16;	/* PIC relocation */
   if (bfd_header_big_endian (abfd))
     {
       reloc->r_index[0] = r_index >> 16;
@@ -209,7 +173,6 @@ MY(put_reloc)(abfd, r_extern, r_index, value, howto, reloc)
 	((r_extern ?     RELOC_STD_BITS_EXTERN_BIG : 0)
 	 | (r_pcrel ?    RELOC_STD_BITS_PCREL_BIG : 0)
 	 | (r_neg ?	 RELOC_ARM_BITS_NEG_BIG : 0)
-	 | (r_pic ?	 RELOC_ARM_BITS_PIC_BIG : 0)
 	 | (r_length <<  RELOC_STD_BITS_LENGTH_SH_BIG));
     }
   else
@@ -221,16 +184,15 @@ MY(put_reloc)(abfd, r_extern, r_index, value, howto, reloc)
 	((r_extern ?     RELOC_STD_BITS_EXTERN_LITTLE : 0)
 	 | (r_pcrel ?    RELOC_STD_BITS_PCREL_LITTLE : 0)
 	 | (r_neg ?	 RELOC_ARM_BITS_NEG_LITTLE : 0)
-	 | (r_pic ?	 RELOC_ARM_BITS_PIC_LITTLE : 0)
 	 | (r_length <<  RELOC_STD_BITS_LENGTH_SH_LITTLE));
     }
 }
- 
+
 #define MY_put_reloc(BFD, EXT, IDX, VAL, HOWTO, RELOC) \
-  MY(put_reloc)(BFD, EXT, IDX, VAL, HOWTO, RELOC)
+  MY(put_reloc) (BFD, EXT, IDX, VAL, HOWTO, RELOC)
 
 void
-MY(relocatable_reloc)(howto, abfd, reloc, amount, r_addr)
+MY(relocatable_reloc) (howto, abfd, reloc, amount, r_addr)
      reloc_howto_type *howto;
      bfd *abfd;
      struct reloc_std_external *reloc;
@@ -239,11 +201,11 @@ MY(relocatable_reloc)(howto, abfd, reloc, amount, r_addr)
 {
   if (howto->type == 3)
     {
-      if (reloc->r_type[0] 
+      if (reloc->r_type[0]
 	  & (bfd_header_big_endian (abfd)
 	     ? RELOC_STD_BITS_EXTERN_BIG : RELOC_STD_BITS_EXTERN_LITTLE))
 	{
-	  /* The reloc is still external, so don't modify anything. */
+	  /* The reloc is still external, so don't modify anything.  */
 	  *amount = 0;
 	}
       else
@@ -262,18 +224,18 @@ MY(relocatable_reloc)(howto, abfd, reloc, amount, r_addr)
 }
 
 #define MY_relocatable_reloc(HOW, BFD, REL, AMOUNT, ADDR) \
-  MY(relocatable_reloc)(HOW, BFD, REL, &(AMOUNT), ADDR)
+  MY(relocatable_reloc) (HOW, BFD, REL, &(AMOUNT), ADDR)
 
 static bfd_reloc_status_type
 MY(fix_pcrel_26_done) (abfd, reloc_entry, symbol, data, input_section,
 		       output_bfd, error_message)
-     bfd *abfd;
-     arelent *reloc_entry;
-     asymbol *symbol;
-     PTR data;
-     asection *input_section;
-     bfd *output_bfd;
-     char **error_message;
+     bfd *abfd ATTRIBUTE_UNUSED;
+     arelent *reloc_entry ATTRIBUTE_UNUSED;
+     asymbol *symbol ATTRIBUTE_UNUSED;
+     PTR data ATTRIBUTE_UNUSED;
+     asection *input_section ATTRIBUTE_UNUSED;
+     bfd *output_bfd ATTRIBUTE_UNUSED;
+     char **error_message ATTRIBUTE_UNUSED;
 {
   /* This is dead simple at present.  */
   return bfd_reloc_ok;
@@ -288,13 +250,13 @@ MY(fix_pcrel_26) (abfd, reloc_entry, symbol, data, input_section,
      PTR data;
      asection *input_section;
      bfd *output_bfd;
-     char **error_message;
+     char **error_message ATTRIBUTE_UNUSED;
 {
   bfd_vma relocation;
   bfd_size_type addr = reloc_entry->address;
   long target = bfd_get_32 (abfd, (bfd_byte *) data + addr);
   bfd_reloc_status_type flag = bfd_reloc_ok;
-  
+
   /* If this is an undefined symbol, return error */
   if (symbol->section == &bfd_und_section
       && (symbol->flags & BSF_WEAK) == 0)
@@ -334,12 +296,12 @@ MY(fix_pcrel_26) (abfd, reloc_entry, symbol, data, input_section,
   /* Now the ARM magic... Change the reloc type so that it is marked as done.
      Strictly this is only necessary if we are doing a partial relocation.  */
   reloc_entry->howto = &MY(howto_table)[7];
-  
+
   return flag;
 }
 
 reloc_howto_type *
-MY(bfd_reloc_type_lookup)(abfd,code)
+MY(bfd_reloc_type_lookup) (abfd,code)
      bfd *abfd;
      bfd_reloc_code_real_type code;
 {
@@ -361,10 +323,6 @@ MY(bfd_reloc_type_lookup)(abfd,code)
       ASTD (BFD_RELOC_8_PCREL, 4);
       ASTD (BFD_RELOC_16_PCREL, 5);
       ASTD (BFD_RELOC_32_PCREL, 6);
-      ASTD (BFD_RELOC_ARM_GOT12, 17);
-      ASTD (BFD_RELOC_ARM_GOT32, 18);
-      ASTD (BFD_RELOC_ARM_GOTPC, 22);
-      ASTD (BFD_RELOC_ARM_JUMP_SLOT, 19);
     default: return (CONST struct reloc_howto_struct *) 0;
     }
 }
@@ -384,7 +342,7 @@ MY_swap_std_reloc_in (abfd, bytes, cache_ptr, symbols, symcount)
      struct reloc_std_external *bytes;
      arelent *cache_ptr;
      asymbol **symbols;
-     bfd_size_type symcount;
+     bfd_size_type symcount ATTRIBUTE_UNUSED;
 {
   int r_index;
   int r_extern;
@@ -410,7 +368,6 @@ MY_swap_std_reloc_out (abfd, g, natptr)
   int r_length;
   int r_pcrel;
   int r_neg = 0;	/* Negative relocs use the BASEREL bit.  */
-  int r_pic = 0;
   asection *output_section = sym->section->output_section;
 
   PUT_WORD(abfd, g->address, natptr->r_address);
@@ -434,20 +391,9 @@ MY_swap_std_reloc_out (abfd, g, natptr)
       r_pcrel = 0;
     }
   else if (g->howto->type == 7)
-    { 
-      r_length = 3;
-      r_pcrel = 1;
-    }
-  
-  /* Is this a PIC relocation? */
-  if (g->howto->type & 16)
-    r_pic = 1;
-
-  /* jmpslot (branch with pic set) is treated like a branch */
-  if (g->howto->type == 19) 
     {
       r_length = 3;
-      r_pcrel = 0;
+      r_pcrel = 1;
     }
 
 #if 0
@@ -486,17 +432,8 @@ MY_swap_std_reloc_out (abfd, g, natptr)
   else
     {
       /* Just an ordinary section */
-      if (r_pic && (g->howto->type == 18))
-	{
-	  /* Fill in symbol */
-	  r_extern = 1;
-	  r_index = (*(g->sym_ptr_ptr))->KEEPIT;
-	}
-      else
-	{
-	  r_extern = 0;
-	  r_index  = output_section->target_index;
-	}
+      r_extern = 0;
+      r_index  = output_section->target_index;
     }
 
   /* now the fun stuff */
@@ -509,7 +446,6 @@ MY_swap_std_reloc_out (abfd, g, natptr)
 	(  (r_extern ?   RELOC_STD_BITS_EXTERN_BIG: 0)
 	 | (r_pcrel  ?   RELOC_STD_BITS_PCREL_BIG: 0)
 	 | (r_neg    ?   RELOC_ARM_BITS_NEG_BIG: 0)
-	 | (r_pic    ?   RELOC_ARM_BITS_PIC_BIG: 0)
 	 | (r_length <<  RELOC_STD_BITS_LENGTH_SH_BIG));
     }
   else
@@ -521,7 +457,6 @@ MY_swap_std_reloc_out (abfd, g, natptr)
 	(  (r_extern ?   RELOC_STD_BITS_EXTERN_LITTLE: 0)
 	 | (r_pcrel  ?   RELOC_STD_BITS_PCREL_LITTLE: 0)
 	 | (r_neg    ?   RELOC_ARM_BITS_NEG_LITTLE: 0)
-	 | (r_pic    ?   RELOC_ARM_BITS_PIC_LITTLE: 0)
 	 | (r_length <<  RELOC_STD_BITS_LENGTH_SH_LITTLE));
     }
 }
@@ -530,6 +465,8 @@ MY_swap_std_reloc_out (abfd, g, natptr)
 
 #include "aout-target.h"
 
+extern const bfd_target aout_arm_big_vec;
+
 const bfd_target aout_arm_little_vec =
 {
   "a.out-arm-little",           /* name */
@@ -566,6 +503,8 @@ const bfd_target aout_arm_little_vec =
      BFD_JUMP_TABLE_LINK (MY),
      BFD_JUMP_TABLE_DYNAMIC (MY),
 
+  & aout_arm_big_vec,
+
   (PTR) MY_backend_data,
 };
 
@@ -605,5 +544,7 @@ const bfd_target aout_arm_big_vec =
      BFD_JUMP_TABLE_LINK (MY),
      BFD_JUMP_TABLE_DYNAMIC (MY),
 
+  & aout_arm_little_vec,
+
   (PTR) MY_backend_data,
 };
