@@ -1,5 +1,6 @@
 /* BFD back-end for Intel 960 COFF files.
-   Copyright (C) 1990, 91, 92, 93, 94, 95, 1997 Free Software Foundation, Inc.
+   Copyright (C) 1990, 91, 92, 93, 94, 95, 97, 98, 1999
+   Free Software Foundation, Inc.
    Written by Cygnus Support.
 
 This file is part of BFD, the Binary File Descriptor library.
@@ -60,7 +61,7 @@ static boolean coff_i960_adjust_symndx
 
 static boolean
 coff_i960_is_local_label_name (abfd, name)
-     bfd *abfd;
+     bfd *abfd ATTRIBUTE_UNUSED;
      const char *name;
 {
   return (name[0] == 'L'
@@ -98,7 +99,7 @@ coff_i960_is_local_label_name (abfd, name)
 #define BAL	 0x0b000000	/* Template for 'bal' instruction	*/
 #define BAL_MASK 0x00ffffff
 
-static bfd_reloc_status_type 
+static bfd_reloc_status_type
 optcall_callback (abfd, reloc_entry, symbol_in, data,
 		  input_section, ignore_bfd, error_message)
      bfd *abfd;
@@ -106,7 +107,7 @@ optcall_callback (abfd, reloc_entry, symbol_in, data,
      asymbol *symbol_in;
      PTR data;
      asection *input_section;
-     bfd *ignore_bfd;
+     bfd *ignore_bfd ATTRIBUTE_UNUSED;
      char **error_message;
 {
   /* This item has already been relocated correctly, but we may be
@@ -116,13 +117,13 @@ optcall_callback (abfd, reloc_entry, symbol_in, data,
   coff_symbol_type *cs = coffsymbol(symbol_in);
 
   /* Don't do anything with symbols which aren't tied up yet,
-     except move the reloc. */
+     except move the reloc.  */
   if (bfd_is_und_section (cs->symbol.section)) {
     reloc_entry->address += input_section->output_offset;
     return bfd_reloc_ok;
   }
-    
-  /* So the target symbol has to be of coff type, and the symbol 
+
+  /* So the target symbol has to be of coff type, and the symbol
      has to have the correct native information within it */
   if ((bfd_asymbol_flavour(&cs->symbol) != bfd_target_coff_flavour)
       || (cs->native == (combined_entry_type *)NULL))
@@ -132,12 +133,12 @@ optcall_callback (abfd, reloc_entry, symbol_in, data,
 	 bout file will cause this match to be true. Should I complain?  This
 	 will only work if the bout symbol is non leaf.  */
       *error_message =
-	(char *) "uncertain calling convention for non-COFF symbol";
+	(char *) _("uncertain calling convention for non-COFF symbol");
       result = bfd_reloc_dangerous;
     }
   else
     {
-    switch (cs->native->u.syment.n_sclass) 
+    switch (cs->native->u.syment.n_sclass)
       {
       case C_LEAFSTAT:
       case C_LEAFEXT:
@@ -145,7 +146,7 @@ optcall_callback (abfd, reloc_entry, symbol_in, data,
 	   to the correct location.  */
 	{
 	  union internal_auxent *aux = &((cs->native+2)->u.auxent);
-	  int word = bfd_get_32(abfd, (bfd_byte *)data + reloc_entry->address);
+	  int word = bfd_get_32 (abfd, (bfd_byte *)data + reloc_entry->address);
 	  int olf = (aux->x_bal.x_balntry - cs->native->u.syment.n_value);
 	  BFD_ASSERT(cs->native->u.syment.n_numaux==2);
 
@@ -155,7 +156,7 @@ optcall_callback (abfd, reloc_entry, symbol_in, data,
 	     sym and auxents untouched, so the delta between the two
 	     is the offset of the bal entry point.  */
 	  word = ((word +  olf)  & BAL_MASK) | BAL;
-  	  bfd_put_32(abfd, word, (bfd_byte *) data + reloc_entry->address);
+  	  bfd_put_32 (abfd, word, (bfd_byte *) data + reloc_entry->address);
   	}
 	result = bfd_reloc_ok;
 	break;
@@ -187,16 +188,16 @@ optcall_callback (abfd, reloc_entry, symbol_in, data,
    useful.  It was used before this target was converted to use the
    COFF specific backend linker.  */
 
-static bfd_reloc_status_type 
+static bfd_reloc_status_type
 coff_i960_relocate (abfd, reloc_entry, symbol, data, input_section,
 		    output_bfd, error_message)
      bfd *abfd;
      arelent *reloc_entry;
      asymbol *symbol;
-     PTR data;
-     asection *input_section;
+     PTR data ATTRIBUTE_UNUSED;
+     asection *input_section ATTRIBUTE_UNUSED;
      bfd *output_bfd;
-     char **error_message;
+     char **error_message ATTRIBUTE_UNUSED;
 {
   asection *osec;
 
@@ -277,7 +278,7 @@ static reloc_howto_type howto_optcall =
 
 static reloc_howto_type *
 coff_i960_reloc_type_lookup (abfd, code)
-     bfd *abfd;
+     bfd *abfd ATTRIBUTE_UNUSED;
      bfd_reloc_code_real_type code;
 {
   switch (code)
@@ -368,7 +369,7 @@ coff_i960_start_final_link (abfd, info)
 static boolean
 coff_i960_relocate_section (output_bfd, info, input_bfd, input_section,
 			    contents, relocs, syms, sections)
-     bfd *output_bfd;
+     bfd *output_bfd ATTRIBUTE_UNUSED;
      struct bfd_link_info *info;
      bfd *input_bfd;
      asection *input_section;
@@ -401,7 +402,7 @@ coff_i960_relocate_section (output_bfd, info, input_bfd, input_section,
 	  sym = NULL;
 	}
       else
-	{    
+	{
 	  h = obj_coff_sym_hashes (input_bfd)[symndx];
 	  sym = syms + symndx;
 	}
@@ -457,7 +458,7 @@ coff_i960_relocate_section (output_bfd, info, input_bfd, input_section,
 	    {
 	      if (! ((*info->callbacks->undefined_symbol)
 		     (info, h->root.root.string, input_bfd, input_section,
-		      rel->r_vaddr - input_section->vma)))
+		      rel->r_vaddr - input_section->vma, true)))
 		return false;
 	    }
 	}
@@ -481,7 +482,7 @@ coff_i960_relocate_section (output_bfd, info, input_bfd, input_section,
                  function.  */
 	      if (! ((*info->callbacks->reloc_dangerous)
 		     (info,
-		      "uncertain calling convention for non-COFF symbol",
+		      _("uncertain calling convention for non-COFF symbol"),
 		      input_bfd, input_section,
 		      rel->r_vaddr - input_section->vma)))
 		return false;
@@ -577,13 +578,12 @@ coff_i960_relocate_section (output_bfd, info, input_bfd, input_section,
    instead be a reloc against the internal symbol we created specially
    for the section.  */
 
-/*ARGSUSED*/
 static boolean
 coff_i960_adjust_symndx (obfd, info, ibfd, sec, irel, adjustedp)
-     bfd *obfd;
-     struct bfd_link_info *info;
+     bfd *obfd ATTRIBUTE_UNUSED;
+     struct bfd_link_info *info ATTRIBUTE_UNUSED;
      bfd *ibfd;
-     asection *sec;
+     asection *sec ATTRIBUTE_UNUSED;
      struct internal_reloc *irel;
      boolean *adjustedp;
 {
@@ -615,49 +615,9 @@ coff_i960_adjust_symndx (obfd, info, ibfd, sec, irel, adjustedp)
 
 #include "coffcode.h"
 
-const bfd_target icoff_little_vec =
-{
-  "coff-Intel-little",		/* name */
-  bfd_target_coff_flavour,
-  BFD_ENDIAN_LITTLE,		/* data byte order is little */
-  BFD_ENDIAN_LITTLE,		/* header byte order is little */
-
-  (HAS_RELOC | EXEC_P |		/* object flags */
-   HAS_LINENO | HAS_DEBUG |
-   HAS_SYMS | HAS_LOCALS | WP_TEXT),
-
-  (SEC_HAS_CONTENTS | SEC_ALLOC | SEC_LOAD | SEC_RELOC), /* section flags */
-  '_',				/* leading underscore */
-  '/',				/* ar_pad_char */
-  15,				/* ar_max_namelen */
-
-  bfd_getl64, bfd_getl_signed_64, bfd_putl64,
-     bfd_getl32, bfd_getl_signed_32, bfd_putl32,
-     bfd_getl16, bfd_getl_signed_16, bfd_putl16, /* data */
-  bfd_getl64, bfd_getl_signed_64, bfd_putl64,
-     bfd_getl32, bfd_getl_signed_32, bfd_putl32,
-     bfd_getl16, bfd_getl_signed_16, bfd_putl16, /* hdrs */
-
- {_bfd_dummy_target, coff_object_p, /* bfd_check_format */
-   bfd_generic_archive_p, _bfd_dummy_target},
- {bfd_false, coff_mkobject,	/* bfd_set_format */
-   _bfd_generic_mkarchive, bfd_false},
- {bfd_false, coff_write_object_contents, /* bfd_write_contents */
-   _bfd_write_archive_contents, bfd_false},
-
-     BFD_JUMP_TABLE_GENERIC (coff),
-     BFD_JUMP_TABLE_COPY (coff),
-     BFD_JUMP_TABLE_CORE (_bfd_nocore),
-     BFD_JUMP_TABLE_ARCHIVE (_bfd_archive_coff),
-     BFD_JUMP_TABLE_SYMBOLS (coff),
-     BFD_JUMP_TABLE_RELOCS (coff),
-     BFD_JUMP_TABLE_WRITE (coff),
-     BFD_JUMP_TABLE_LINK (coff),
-     BFD_JUMP_TABLE_DYNAMIC (_bfd_nodynamic),
-
-  COFF_SWAP_TABLE,
-};
+extern const bfd_target icoff_big_vec;
 
+CREATE_LITTLE_COFF_TARGET_VEC (icoff_little_vec, "coff-Intel-little", 0, 0, '_', & icoff_big_vec)
 
 const bfd_target icoff_big_vec =
 {
@@ -699,5 +659,7 @@ bfd_getb64, bfd_getb_signed_64, bfd_putb64,
      BFD_JUMP_TABLE_LINK (coff),
      BFD_JUMP_TABLE_DYNAMIC (_bfd_nodynamic),
 
-  COFF_SWAP_TABLE,
+  & icoff_little_vec,
+
+  COFF_SWAP_TABLE
 };
