@@ -41,9 +41,17 @@ _bfd_elf_create_got_section (abfd, info)
 
   switch (bed->s->arch_size)
     {
-    case 32: ptralign = 2; break;
-    case 64: ptralign = 3; break;
-    default: abort();
+    case 32:
+      ptralign = 2;
+      break;
+
+    case 64:
+      ptralign = 3;
+      break;
+
+    default:
+      bfd_set_error (bfd_error_bad_value);
+      return false;
     }
 
   flags = (SEC_ALLOC | SEC_LOAD | SEC_HAS_CONTENTS | SEC_IN_MEMORY
@@ -89,7 +97,6 @@ _bfd_elf_create_got_section (abfd, info)
   return true;
 }
 
-
 /* Create dynamic sections when linking against a dynamic object.  */
 
 boolean
@@ -104,9 +111,17 @@ _bfd_elf_create_dynamic_sections (abfd, info)
 
   switch (bed->s->arch_size)
     {
-    case 32: ptralign = 2; break;
-    case 64: ptralign = 3; break;
-    default: abort();
+    case 32:
+      ptralign = 2;
+      break;
+
+    case 64:
+      ptralign = 3;
+      break;
+
+    default:
+      bfd_set_error (bfd_error_bad_value);
+      return false;
     }
 
   /* We need to create .plt, .rel[a].plt, .got, .got.plt, .dynbss, and
@@ -147,7 +162,7 @@ _bfd_elf_create_dynamic_sections (abfd, info)
 	return false;
     }
 
-  s = bfd_make_section (abfd, 
+  s = bfd_make_section (abfd,
 			bed->default_use_rela_p ? ".rela.plt" : ".rel.plt");
   if (s == NULL
       || ! bfd_set_section_flags (abfd, s, flags | SEC_READONLY)
@@ -183,9 +198,9 @@ _bfd_elf_create_dynamic_sections (abfd, info)
      copy relocs.  */
       if (! info->shared)
 	{
-	  s = bfd_make_section (abfd, 
-				(bed->default_use_rela_p 
-				 ? ".rela.bss" : ".rel.bss")); 
+	  s = bfd_make_section (abfd,
+				(bed->default_use_rela_p
+				 ? ".rela.bss" : ".rel.bss"));
 	  if (s == NULL
 	      || ! bfd_set_section_flags (abfd, s, flags | SEC_READONLY)
 	      || ! bfd_set_section_alignment (abfd, s, ptralign))
@@ -196,7 +211,6 @@ _bfd_elf_create_dynamic_sections (abfd, info)
   return true;
 }
 
-
 /* Record a new dynamic symbol.  We record the dynamic symbols as we
    read the input files, since we need to have a list of all of them
    before we can determine the final sizes of the output sections.
@@ -226,20 +240,13 @@ _bfd_elf_link_record_dynamic_symbol (info, h)
 	{
 	case STV_INTERNAL:
 	case STV_HIDDEN:
-	  /* This symbol must be defined in the shared object or
-	     executable.  */
-	  if (h->root.type == bfd_link_hash_undefined)
+	  if (h->root.type != bfd_link_hash_undefined
+	      && h->root.type != bfd_link_hash_undefweak)
 	    {
-	      bfd * abfd = h->root.u.undef.abfd;
-	      const char * name = h->root.root.string;
-	      
-	      (*info->callbacks->undefined_symbol)
-		(info, name, abfd, bfd_und_section_ptr, 0, true);
+	      h->elf_link_hash_flags |= ELF_LINK_FORCED_LOCAL;
+	      return true;
 	    }
-	  
-	  h->elf_link_hash_flags |= ELF_LINK_FORCED_LOCAL;
-	  break;
-	  
+
 	default:
 	  break;
 	}
@@ -489,7 +496,6 @@ _bfd_elf_create_linker_section (abfd, info, which, defaults)
 
   return lsect;
 }
-
 
 /* Find a linker generated pointer with a given addend and type.  */
 
@@ -507,7 +513,6 @@ _bfd_elf_find_pointer_linker_section (linker_pointers, addend, which)
 
   return (elf_linker_section_pointers_t *)0;
 }
-
 
 /* Make the .rela section corresponding to the generated linker section.  */
 
