@@ -1,5 +1,6 @@
 /* BFD back-end for linux flavored m68k a.out binaries.
-   Copyright (C) 1992, 93, 94, 95, 96, 1997 Free Software Foundation, Inc.
+   Copyright (C) 1992, 93, 94, 95, 96, 97, 98, 1999
+   Free Software Foundation, Inc.
 
 This file is part of BFD, the Binary File Descriptor library.
 
@@ -301,7 +302,7 @@ new_fixup (info, h, value, builtin)
 static boolean
 linux_link_create_dynamic_sections (abfd, info)
      bfd *abfd;
-     struct bfd_link_info *info;
+     struct bfd_link_info *info ATTRIBUTE_UNUSED;
 {
   flagword flags;
   register asection *s;
@@ -450,7 +451,7 @@ linux_tally_symbols (h, data)
 	alloc = (char *) bfd_malloc (strlen (name) + 1);
 
       if (p == NULL || alloc == NULL)
-	(*_bfd_error_handler) ("Output file requires shared library `%s'\n",
+	(*_bfd_error_handler) (_("Output file requires shared library `%s'\n"),
 			       name);
       else
 	{
@@ -458,7 +459,7 @@ linux_tally_symbols (h, data)
 	  p = strrchr (alloc, '_');
 	  *p++ = '\0';
 	  (*_bfd_error_handler)
-	    ("Output file requires shared library `%s.so.%s'\n",
+	    (_("Output file requires shared library `%s.so.%s'\n"),
 	     alloc, p);
 	  free (alloc);
 	}
@@ -478,8 +479,8 @@ linux_tally_symbols (h, data)
 				   (h->root.root.root.string
 				    + sizeof PLT_REF_PREFIX - 1),
 				   false, false, true);
-      /* h2 does not follow indirect symbols. */
-      h2 = linux_link_hash_lookup (linux_hash_table (info), 
+      /* h2 does not follow indirect symbols.  */
+      h2 = linux_link_hash_lookup (linux_hash_table (info),
 				   (h->root.root.root.string
 				    + sizeof PLT_REF_PREFIX - 1),
 				   false, false, false);
@@ -535,7 +536,7 @@ linux_tally_symbols (h, data)
 	}
 
       /* Quick and dirty way of stripping these symbols from the
-	 symtab. */
+	 symtab.  */
       if (bfd_is_abs_section (h->root.root.u.def.section))
 	h->root.written = true;
     }
@@ -560,7 +561,7 @@ bfd_m68klinux_size_dynamic_sections (output_bfd, info)
   if (output_bfd->xvec != &MY(vec))
     return true;
 
-  /* First find the fixups... */
+  /* First find the fixups...  */
   linux_link_hash_traverse (linux_hash_table (info),
 			    linux_tally_symbols,
 			    (PTR) info);
@@ -630,7 +631,7 @@ linux_finish_dynamic_link (output_bfd, info)
   fixups_written = 0;
 
 #ifdef LINUX_LINK_DEBUG
-  printf ("Fixup table file offset: %x  VMA: %x\n", 
+  printf ("Fixup table file offset: %x  VMA: %x\n",
 	  os->filepos + s->output_offset,
 	  os->vma + s->output_offset);
 #endif
@@ -649,7 +650,7 @@ linux_finish_dynamic_link (output_bfd, info)
 	  && f->h->root.root.type != bfd_link_hash_defweak)
 	{
 	  (*_bfd_error_handler)
-	    ("Symbol %s not defined for fixups\n",
+	    (_("Symbol %s not defined for fixups\n"),
 	     f->h->root.root.root.string);
 	  continue;
 	}
@@ -697,7 +698,7 @@ linux_finish_dynamic_link (output_bfd, info)
 	      && f->h->root.root.type != bfd_link_hash_defweak)
 	    {
 	      (*_bfd_error_handler)
-		("Symbol %s not defined for fixups\n",
+		(_("Symbol %s not defined for fixups\n"),
 		 f->h->root.root.root.string);
 	      continue;
 	    }
@@ -721,7 +722,7 @@ linux_finish_dynamic_link (output_bfd, info)
 
   if (linux_hash_table (info)->fixup_count != fixups_written)
     {
-      (*_bfd_error_handler) ("Warning: fixup count mismatch\n");
+      (*_bfd_error_handler) (_("Warning: fixup count mismatch\n"));
       while (linux_hash_table (info)->fixup_count > fixups_written)
 	{
 	  bfd_put_32 (output_bfd, 0, fixup_table);
@@ -732,7 +733,7 @@ linux_finish_dynamic_link (output_bfd, info)
 	}
     }
 
-  h = linux_link_hash_lookup (linux_hash_table (info), 
+  h = linux_link_hash_lookup (linux_hash_table (info),
 			      "__BUILTIN_FIXUPS__",
 			      false, false, false);
 
