@@ -1,5 +1,6 @@
 /* HP PA-RISC SOM object file format:  definitions internal to BFD.
-   Copyright (C) 1990, 91, 92, 93, 94 Free Software Foundation, Inc.
+   Copyright (C) 1990, 91, 92, 93, 94, 95, 96, 1998
+   Free Software Foundation, Inc.
 
    Contributed by the Center for Software Science at the
    University of Utah (pa-gdb-bugs@cs.utah.edu).
@@ -18,12 +19,12 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
+   02111-1307, USA.  */
 
 #ifndef _SOM_H
 #define _SOM_H
 
-#include "../bfd/sysdep.h"
 #include "libhppa.h"
 
 #include <a.out.h>
@@ -45,8 +46,8 @@
 #define _PA_RISC_ID(__m_num) 1
 #endif /* HOST_HPPABSD */
 
-#define FILE_HDR_SIZE sizeof(struct header)
-#define AUX_HDR_SIZE sizeof(struct som_exec_auxhdr)
+#define FILE_HDR_SIZE sizeof (struct header)
+#define AUX_HDR_SIZE sizeof (struct som_exec_auxhdr)
 
 typedef struct som_symbol
   {
@@ -57,7 +58,11 @@ typedef struct som_symbol
        in GAS this way.  */
     union
       {
-	unsigned int hppa_arg_reloc;
+	struct
+	{
+	  unsigned int hppa_arg_reloc;
+	  unsigned int hppa_priv_level;
+	} ap;
 	PTR any;
       }
     tc_data;
@@ -72,7 +77,7 @@ typedef struct som_symbol
     int reloc_count;
 
     /* During object file writing, the offset of the name of this symbol
-       in the SOM string table. */
+       in the SOM string table.  */
     int stringtab_offset;
   }
 som_symbol_type;
@@ -108,6 +113,7 @@ struct somdata
     struct copyright_aux_hdr *copyright_aux_hdr;
     struct user_string_aux_hdr *version_aux_hdr;
     struct som_exec_auxhdr *exec_hdr;
+    COMPUNIT *comp_unit;
 
     /* Pointers to a saved copy of the symbol and string tables.  These
        need not be copied for objcopy or strip to work.  */
@@ -153,7 +159,7 @@ struct som_copyable_section_data_struct
     int space_number;
 
     /* Add more stuff here as needed.  Good examples of information
-       we might want to pass would be initialization pointers, 
+       we might want to pass would be initialization pointers,
        and the many subspace flags we do not represent yet.  */
   };
 
@@ -161,7 +167,7 @@ struct som_copyable_section_data_struct
 
    reloc_size holds the size of the relocation stream, note this
    is very different from the number of relocations as SOM relocations
-   are variable length. 
+   are variable length.
 
    reloc_stream is the actual stream of relocation entries.  */
 
@@ -180,6 +186,7 @@ struct som_section_data_struct
 #define obj_som_exec_hdr(bfd)		(somdata(bfd).exec_hdr)
 #define obj_som_copyright_hdr(bfd)	(somdata(bfd).copyright_aux_hdr)
 #define obj_som_version_hdr(bfd)	(somdata(bfd).version_aux_hdr)
+#define obj_som_compilation_unit(bfd)	(somdata(bfd).comp_unit)
 #define obj_som_symtab(bfd)		(somdata(bfd).symtab)
 #define obj_som_stringtab(bfd)		(somdata(bfd).stringtab)
 #define obj_som_sym_filepos(bfd)	(somdata(bfd).sym_filepos)
@@ -191,14 +198,13 @@ struct som_section_data_struct
   ((struct som_section_data_struct *)sec->used_by_bfd)
 #define som_symbol_data(symbol)		((som_symbol_type *) symbol)
 
-
 /* Defines groups of basic relocations.  FIXME:  These should
    be the only basic relocations created by GAS.  The rest
    should be internal to the BFD backend.
 
    The idea is both SOM and ELF define these basic relocation
    types so they map into a SOM or ELF specific reloation as
-   appropriate.  This allows GAS to share much more code 
+   appropriate.  This allows GAS to share much more code
    between the two object formats.  */
 
 #define R_HPPA_NONE			R_NO_RELOCATION
@@ -222,5 +228,9 @@ boolean bfd_som_set_subsection_attributes PARAMS ((asection *, asection *,
 void bfd_som_set_symbol_type PARAMS ((asymbol *, unsigned int));
 boolean bfd_som_attach_aux_hdr PARAMS ((bfd *, int, char *));
 int ** hppa_som_gen_reloc_type
-  PARAMS ((bfd *, int, int, enum hppa_reloc_field_selector_type_alt, int));
+  PARAMS ((bfd *, int, int, enum hppa_reloc_field_selector_type_alt,
+	   int, asymbol *));
+boolean bfd_som_attach_compilation_unit
+  PARAMS ((bfd *, const char *, const char *, const char *, const char *));
+
 #endif /* _SOM_H */
