@@ -1,5 +1,6 @@
 /* BFD back-end for linux flavored sparc a.out binaries.
-   Copyright (C) 1992, 93, 94, 95, 1996 Free Software Foundation, Inc.
+   Copyright (C) 1992, 93, 94, 95, 96, 97, 98, 1999
+   Free Software Foundation, Inc.
 
 This file is part of BFD, the Binary File Descriptor library.
 
@@ -18,9 +19,9 @@ along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 USA.  */
 
-#define        TARGET_PAGE_SIZE        4096
+#define TARGET_PAGE_SIZE        4096
 #define ZMAGIC_DISK_BLOCK_SIZE 1024
-#define        SEGMENT_SIZE TARGET_PAGE_SIZE
+#define SEGMENT_SIZE TARGET_PAGE_SIZE
 #define TEXT_START_ADDR        0x0
 #define N_SHARED_LIB(x) 0
 #define BYTES_IN_WORD 4
@@ -48,6 +49,9 @@ extern const bfd_target MY(vec);
 static void MY_final_link_callback
   PARAMS ((bfd *, file_ptr *, file_ptr *, file_ptr *));
 
+static boolean sparclinux_bfd_final_link
+  PARAMS ((bfd *abfd, struct bfd_link_info *info));
+
 static boolean
 sparclinux_bfd_final_link (abfd, info)
      bfd *abfd;
@@ -61,6 +65,8 @@ sparclinux_bfd_final_link (abfd, info)
 
 /* Set the machine type correctly.  */
 
+static boolean sparclinux_write_object_contents PARAMS ((bfd *abfd));
+
 static boolean
 sparclinux_write_object_contents (abfd)
      bfd *abfd;
@@ -89,7 +95,7 @@ sparclinux_write_object_contents (abfd)
 #define IS_GOT_SYM(name) \
   (strncmp (name, GOT_REF_PREFIX, sizeof GOT_REF_PREFIX - 1) == 0)
 
-/* See if a symbol name is a reference to the procedure linkage table. */
+/* See if a symbol name is a reference to the procedure linkage table.  */
 
 #ifndef PLT_REF_PREFIX
 #define        PLT_REF_PREFIX  "__PLT_"
@@ -119,7 +125,7 @@ sparclinux_write_object_contents (abfd)
    each fixup contains two 32 bit numbers.  A regular fixup contains
    an address and a pointer, and at runtime we should store the
    address at the location pointed to by the pointer.  A builtin fixup
-   contains two pointers, and we should read the address using on
+   contains two pointers, and we should read the address using one
    pointer and store it at the location pointed to by the other
    pointer.  Builtin fixups come into play when we have duplicate
    __GOT__ symbols for the same variable.  The builtin fixup will copy
@@ -191,6 +197,7 @@ linux_link_hash_newfunc (entry, table, string)
      const char *string;
 {
   struct linux_link_hash_entry *ret = (struct linux_link_hash_entry *) entry;
+
   /* Allocate the structure if it has not already been allocated by a
      subclass.  */
   if (ret == (struct linux_link_hash_entry *) NULL)
@@ -239,6 +246,7 @@ linux_link_hash_table_create (abfd)
 }
 
 /* Look up an entry in a Linux link hash table.  */
+
 #define linux_link_hash_lookup(table, string, create, copy, follow) \
   ((struct linux_link_hash_entry *) \
    aout_link_hash_lookup (&(table)->root, (string), (create), (copy),\
@@ -255,7 +263,7 @@ linux_link_hash_table_create (abfd)
 /* Get the Linux link hash table from the info structure.  This is
    just a cast.  */
 
-#define linux_hash_table(p) ((struct linux_link_hash_table *)((p)->hash))
+#define linux_hash_table(p) ((struct linux_link_hash_table *) ((p)->hash))
 
 /* Store the information for a new fixup.  */
 
@@ -292,7 +300,7 @@ new_fixup (info, h, value, builtin)
 static boolean
 linux_link_create_dynamic_sections (abfd, info)
      bfd *abfd;
-     struct bfd_link_info *info;
+     struct bfd_link_info *info ATTRIBUTE_UNUSED;
 {
   flagword flags;
   register asection *s;
@@ -380,7 +388,7 @@ linux_add_one_symbol (info, abfd, name, flags, section, value, string,
     }
 
   /* Do the usual procedure for adding a symbol.  */
-  if (! _bfd_generic_link_add_one_symbol (info, abfd, name, flags,section,
+  if (! _bfd_generic_link_add_one_symbol (info, abfd, name, flags, section,
                                          value, string, copy, collect,
                                          hashp))
     return false;
@@ -399,7 +407,7 @@ linux_add_one_symbol (info, abfd, name, flags, section, value, string,
 
       if (! (_bfd_generic_link_add_one_symbol
             (info, linux_hash_table (info)->dynobj, SHARABLE_CONFLICTS,
-             BSF_GLOBAL | BSF_CONSTRUCTOR, s, 0, NULL, false, false,NULL)))
+             BSF_GLOBAL | BSF_CONSTRUCTOR, s, 0, NULL, false, false, NULL)))
        return false;
     }
 
@@ -441,7 +449,7 @@ linux_tally_symbols (h, data)
        alloc = (char *) bfd_malloc (strlen (name) + 1);
 
       if (p == NULL || alloc == NULL)
-       (*_bfd_error_handler) ("Output file requires shared library `%s'\n",
+       (*_bfd_error_handler) (_("Output file requires shared library `%s'\n"),
                               name);
       else
        {
@@ -449,7 +457,7 @@ linux_tally_symbols (h, data)
          p = strrchr (alloc, '_');
          *p++ = '\0';
          (*_bfd_error_handler)
-           ("Output file requires shared library `%s.so.%s'\n",
+           (_("Output file requires shared library `%s.so.%s'\n"),
             alloc, p);
          free (alloc);
        }
@@ -457,7 +465,8 @@ linux_tally_symbols (h, data)
       abort ();
     }
 
-  /* If this symbol is not a PLT/GOT, we do not even need to look at it*/
+  /* If this symbol is not a PLT/GOT, we do not even need to look at
+     it.  */
   is_plt = IS_PLT_SYM (h->root.root.root.string);
 
   if (is_plt || IS_GOT_SYM (h->root.root.root.string))
@@ -469,7 +478,7 @@ linux_tally_symbols (h, data)
                                   (h->root.root.root.string
                                    + sizeof PLT_REF_PREFIX - 1),
                                   false, false, true);
-      /* h2 does not follow indirect symbols. */
+      /* h2 does not follow indirect symbols.  */
       h2 = linux_link_hash_lookup (linux_hash_table (info),
                                   (h->root.root.root.string
                                    + sizeof PLT_REF_PREFIX - 1),
@@ -504,7 +513,7 @@ linux_tally_symbols (h, data)
              if (! exists
                  && bfd_is_abs_section (h->root.root.u.def.section))
                {
-                 f = new_fixup (info, h1, f1->h->root.root.u.def.value,0);
+                 f = new_fixup (info, h1, f1->h->root.root.u.def.value, 0);
                  f->jump = is_plt;
                }
              f1->h = h1;
@@ -524,8 +533,9 @@ linux_tally_symbols (h, data)
              f->jump = is_plt;
            }
        }
+
       /* Quick and dirty way of stripping these symbols from the
-        symtab. */
+        symtab.  */
       if (bfd_is_abs_section (h->root.root.u.def.section))
        h->root.written = true;
     }
@@ -550,7 +560,7 @@ bfd_sparclinux_size_dynamic_sections (output_bfd, info)
   if (output_bfd->xvec != &MY(vec))
     return true;
 
-  /* First find the fixups... */
+  /* First find the fixups...  */
   linux_link_hash_traverse (linux_hash_table (info),
                            linux_tally_symbols,
                            (PTR) info);
@@ -623,7 +633,7 @@ linux_finish_dynamic_link (output_bfd, info)
 #endif
 
   fixup_table = s->contents;
-  bfd_put_32 (output_bfd, linux_hash_table (info)->fixup_count,fixup_table);
+  bfd_put_32 (output_bfd, linux_hash_table (info)->fixup_count, fixup_table);
   fixup_table += 4;
 
   /* Fill in fixup table.  */
@@ -636,7 +646,7 @@ linux_finish_dynamic_link (output_bfd, info)
          && f->h->root.root.type != bfd_link_hash_defweak)
        {
          (*_bfd_error_handler)
-           ("Symbol %s not defined for fixups\n",
+           (_("Symbol %s not defined for fixups\n"),
             f->h->root.root.root.string);
          continue;
        }
@@ -677,7 +687,7 @@ linux_finish_dynamic_link (output_bfd, info)
       bfd_put_32 (output_bfd, 0, fixup_table);
       fixup_table += 4;
       ++fixups_written;
-      for (f = linux_hash_table (info)->fixup_list; f != NULL; f =f->next)
+      for (f = linux_hash_table (info)->fixup_list; f != NULL; f = f->next)
        {
          if (! f->builtin)
            continue;
@@ -686,7 +696,7 @@ linux_finish_dynamic_link (output_bfd, info)
              && f->h->root.root.type != bfd_link_hash_defweak)
            {
              (*_bfd_error_handler)
-               ("Symbol %s not defined for fixups\n",
+               (_("Symbol %s not defined for fixups\n"),
                 f->h->root.root.root.string);
              continue;
            }
@@ -710,7 +720,7 @@ linux_finish_dynamic_link (output_bfd, info)
 
   if (linux_hash_table (info)->fixup_count != fixups_written)
     {
-      (*_bfd_error_handler) ("Warning: fixup count mismatch\n");
+      (*_bfd_error_handler) (_("Warning: fixup count mismatch\n"));
       while (linux_hash_table (info)->fixup_count > fixups_written)
        {
          bfd_put_32 (output_bfd, 0, fixup_table);
@@ -742,7 +752,7 @@ linux_finish_dynamic_link (output_bfd, info)
   else
     bfd_put_32 (output_bfd, 0, fixup_table);
 
-  if (bfd_seek (output_bfd, os->filepos + s->output_offset, SEEK_SET) !=0)
+  if (bfd_seek (output_bfd, os->filepos + s->output_offset, SEEK_SET) != 0)
     return false;
 
   if (bfd_write ((PTR) s->contents, 1, s->_raw_size, output_bfd)
