@@ -1,5 +1,5 @@
 /* Generic symbol-table support for the BFD library.
-   Copyright (C) 1990, 91, 92, 93, 94, 95, 96, 97, 98, 1999
+   Copyright (C) 1990, 91, 92, 93, 94, 95, 96, 97, 98, 99, 2000
    Free Software Foundation, Inc.
    Written by Cygnus Support.
 
@@ -91,7 +91,6 @@ SUBSECTION
 	All storage for the symbols themselves is in an objalloc
 	connected to the BFD; it is freed when the BFD is closed.
 
-
 INODE
 Writing Symbols, Mini Symbols, Reading Symbols, Symbols
 SUBSECTION
@@ -163,8 +162,6 @@ SUBSECTION
 
 */
 
-
-
 /*
 DOCDD
 INODE
@@ -390,14 +387,12 @@ DESCRIPTION
 	Return the actual number of symbol pointers, not
 	including the NULL.
 
-
 .#define bfd_canonicalize_symtab(abfd, location) \
 .     BFD_SEND (abfd, _bfd_canonicalize_symtab,\
 .                  (abfd, location))
 
 */
 
-
 /*
 FUNCTION
 	bfd_set_symtab
@@ -474,7 +469,6 @@ bfd_print_symbol_vandf (arg, symbol)
 	       : ((type & BSF_OBJECT) ? 'O' : ' '))));
 }
 
-
 /*
 FUNCTION
 	bfd_make_empty_symbol
@@ -537,7 +531,7 @@ static CONST struct section_to_type stt[] =
 };
 
 /* Return the single-character symbol type corresponding to
-   section S, or '?' for an unknown COFF section.  
+   section S, or '?' for an unknown COFF section.
 
    Check for any leading string which matches, so .text5 returns
    't' as well as .text */
@@ -548,7 +542,7 @@ coff_section_type (s)
 {
   CONST struct section_to_type *t;
 
-  for (t = &stt[0]; t->section; t++) 
+  for (t = &stt[0]; t->section; t++)
     if (!strncmp (s, t->section, strlen (t->section)))
       return t->type;
 
@@ -584,14 +578,28 @@ bfd_decode_symclass (symbol)
   if (bfd_is_und_section (symbol->section))
     {
       if (symbol->flags & BSF_WEAK)
-	return 'w';
+	{
+	  /* If weak, determine if it's specifically an object
+	     or non-object weak.  */
+	  if (symbol->flags & BSF_OBJECT)
+	    return 'v';
+	  else
+	    return 'w';
+	}
       else
 	return 'U';
     }
   if (bfd_is_ind_section (symbol->section))
     return 'I';
   if (symbol->flags & BSF_WEAK)
-    return 'W';
+    {
+      /* If weak, determine if it's specifically an object
+	 or non-object weak.  */
+      if (symbol->flags & BSF_OBJECT)
+	return 'V';
+      else
+	return 'W';
+    }
   if (!(symbol->flags & (BSF_GLOBAL | BSF_LOCAL)))
     return '?';
 
@@ -615,6 +623,26 @@ bfd_decode_symclass (symbol)
      */
 }
 
+/*
+FUNCTION
+	bfd_is_undefined_symclass
+
+DESCRIPTION
+	Returns non-zero if the class symbol returned by
+	bfd_decode_symclass represents an undefined symbol.
+	Returns zero otherwise.
+
+SYNOPSIS
+	boolean bfd_is_undefined_symclass (int symclass);
+*/
+
+boolean
+bfd_is_undefined_symclass (symclass)
+     int symclass;
+{
+  return symclass == 'U' || symclass == 'w' || symclass == 'v';
+}
+
 /*
 FUNCTION
 	bfd_symbol_info
@@ -634,10 +662,12 @@ bfd_symbol_info (symbol, ret)
      symbol_info *ret;
 {
   ret->type = bfd_decode_symclass (symbol);
-  if (ret->type != 'U' && ret->type != 'w')
-    ret->value = symbol->value + symbol->section->vma;
-  else
+
+  if (bfd_is_undefined_symclass (ret->type))
     ret->value = 0;
+  else
+    ret->value = symbol->value + symbol->section->vma;
+
   ret->name = symbol->name;
 }
 
@@ -752,8 +782,8 @@ struct indexentry
 
 static int
 cmpindexentry (a, b)
-     const PTR *a;
-     const PTR *b;
+     const PTR a;
+     const PTR b;
 {
   const struct indexentry *contestantA = (const struct indexentry *) a;
   const struct indexentry *contestantB = (const struct indexentry *) b;
@@ -969,7 +999,7 @@ _bfd_stab_section_find_nearest_line (abfd, symbols, section, offset, pfound,
 	      if (bfd_get_32 (abfd, stab + STRDXOFF) == 0)
 		continue;
 
-	      /* if we did not see a function def, leave space for one. */
+	      /* if we did not see a function def, leave space for one.  */
 	      if (saw_fun == 0)
 		++info->indextablesize;
 
@@ -991,7 +1021,7 @@ _bfd_stab_section_find_nearest_line (abfd, symbols, section, offset, pfound,
 
       if (saw_fun == 0)
 	++info->indextablesize;
-      
+
       if (info->indextablesize == 0)
 	return true;
       ++info->indextablesize;
@@ -1027,8 +1057,8 @@ _bfd_stab_section_find_nearest_line (abfd, symbols, section, offset, pfound,
 	      /* The following code creates a new indextable entry with
 	         a NULL function name if there were no N_FUNs in a file.
 	         Note that a N_SO without a file name is an EOF and
-	         there could be 2 N_SO following it with the new filename 
-	         and directory. */
+	         there could be 2 N_SO following it with the new filename
+	         and directory.  */
 	      if (saw_fun == 0)
 		{
 		  info->indextable[i].val = bfd_get_32 (abfd, last_stab + VALOFF);
@@ -1040,7 +1070,7 @@ _bfd_stab_section_find_nearest_line (abfd, symbols, section, offset, pfound,
 		  ++i;
 		}
 	      saw_fun = 0;
-	      
+
 	      file_name = (char *) str + bfd_get_32 (abfd, stab + STRDXOFF);
 	      if (*file_name == '\0')
 		{
@@ -1226,7 +1256,7 @@ _bfd_stab_section_find_nearest_line (abfd, symbols, section, offset, pfound,
 
   *pfound = true;
 
-  if (file_name[0] == '/' || directory_name == NULL)
+  if (IS_ABSOLUTE_PATH(file_name) || directory_name == NULL)
     *pfilename = file_name;
   else
     {
