@@ -1,45 +1,44 @@
 
 /*  A Bison parser, made from nlmheader.y
- by  GNU Bison version 1.25
-  */
+    by GNU Bison version 1.28  */
 
 #define YYBISON 1  /* Identify Bison output.  */
 
-#define	CHECK	258
-#define	CODESTART	259
-#define	COPYRIGHT	260
-#define	CUSTOM	261
-#define	DATE	262
-#define	DEBUG	263
-#define	DESCRIPTION	264
-#define	EXIT	265
-#define	EXPORT	266
-#define	FLAG_ON	267
-#define	FLAG_OFF	268
-#define	FULLMAP	269
-#define	HELP	270
-#define	IMPORT	271
-#define	INPUT	272
-#define	MAP	273
-#define	MESSAGES	274
-#define	MODULE	275
-#define	MULTIPLE	276
-#define	OS_DOMAIN	277
-#define	OUTPUT	278
-#define	PSEUDOPREEMPTION	279
-#define	REENTRANT	280
-#define	SCREENNAME	281
-#define	SHARELIB	282
-#define	STACK	283
-#define	START	284
-#define	SYNCHRONIZE	285
-#define	THREADNAME	286
-#define	TYPE	287
-#define	VERBOSE	288
-#define	VERSIONK	289
-#define	XDCDATA	290
-#define	STRING	291
-#define	QUOTED_STRING	292
+#define	CHECK	257
+#define	CODESTART	258
+#define	COPYRIGHT	259
+#define	CUSTOM	260
+#define	DATE	261
+#define	DEBUG	262
+#define	DESCRIPTION	263
+#define	EXIT	264
+#define	EXPORT	265
+#define	FLAG_ON	266
+#define	FLAG_OFF	267
+#define	FULLMAP	268
+#define	HELP	269
+#define	IMPORT	270
+#define	INPUT	271
+#define	MAP	272
+#define	MESSAGES	273
+#define	MODULE	274
+#define	MULTIPLE	275
+#define	OS_DOMAIN	276
+#define	OUTPUT	277
+#define	PSEUDOPREEMPTION	278
+#define	REENTRANT	279
+#define	SCREENNAME	280
+#define	SHARELIB	281
+#define	STACK	282
+#define	START	283
+#define	SYNCHRONIZE	284
+#define	THREADNAME	285
+#define	TYPE	286
+#define	VERBOSE	287
+#define	VERSIONK	288
+#define	XDCDATA	289
+#define	STRING	290
+#define	QUOTED_STRING	291
 
 #line 1 "nlmheader.y"
 /* nlmheader.y - parse NLM header specification keywords.
@@ -172,7 +171,7 @@ typedef union
 #define	YYFLAG		-32768
 #define	YYNTBASE	40
 
-#define YYTRANSLATE(x) ((unsigned)(x) <= 292 ? yytranslate[x] : 50)
+#define YYTRANSLATE(x) ((unsigned)(x) <= 291 ? yytranslate[x] : 50)
 
 static const char yytranslate[] = {     0,
      2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
@@ -200,11 +199,11 @@ static const char yytranslate[] = {     0,
      2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
      2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
      2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
-     2,     2,     2,     2,     2,     1,     2,     3,     4,     5,
-     6,     7,     8,     9,    10,    11,    12,    13,    14,    15,
-    16,    17,    18,    19,    20,    21,    22,    23,    24,    25,
-    26,    27,    28,    29,    30,    31,    32,    33,    34,    35,
-    36,    37
+     2,     2,     2,     2,     2,     1,     3,     4,     5,     6,
+     7,     8,     9,    10,    11,    12,    13,    14,    15,    16,
+    17,    18,    19,    20,    21,    22,    23,    24,    25,    26,
+    27,    28,    29,    30,    31,    32,    33,    34,    35,    36,
+    37
 };
 
 #if YYDEBUG != 0
@@ -336,7 +335,8 @@ static const short yycheck[] = {     3,
     -1,    48,    -1,    -1,    68
 };
 /* -*-C-*-  Note some compilers choke on comments on `#line' lines.  */
-#line 3 "/usr/lib/bison.simple"
+#line 3 "/usr/share/misc/bison.simple"
+/* This file comes from bison-1.28.  */
 
 /* Skeleton output parser for bison,
    Copyright (C) 1984, 1989, 1990 Free Software Foundation, Inc.
@@ -353,47 +353,67 @@ static const short yycheck[] = {     3,
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   Foundation, Inc., 59 Temple Place - Suite 330,
+   Boston, MA 02111-1307, USA.  */
 
 /* As a special exception, when this file is copied by Bison into a
    Bison output file, you may use that output file without restriction.
    This special exception was added by the Free Software Foundation
    in version 1.24 of Bison.  */
 
-#ifndef alloca
-#ifdef __GNUC__
-#define alloca __builtin_alloca
-#else /* not GNU C.  */
-#if (!defined (__STDC__) && defined (sparc)) || defined (__sparc__) || defined (__sparc) || defined (__sgi)
-#include <alloca.h>
-#else /* not sparc */
-#if defined (MSDOS) && !defined (__TURBOC__)
-#include <malloc.h>
-#else /* not MSDOS, or __TURBOC__ */
-#if defined(_AIX)
-#include <malloc.h>
- #pragma alloca
-#else /* not MSDOS, __TURBOC__, or _AIX */
-#ifdef __hpux
-#ifdef __cplusplus
-extern "C" {
-void *alloca (unsigned int);
-};
-#else /* not __cplusplus */
-void *alloca ();
-#endif /* not __cplusplus */
-#endif /* __hpux */
-#endif /* not _AIX */
-#endif /* not MSDOS, or __TURBOC__ */
-#endif /* not sparc.  */
-#endif /* not GNU C.  */
-#endif /* alloca not defined.  */
-
 /* This is the parser code that is written into each bison parser
   when the %semantic_parser declaration is not specified in the grammar.
   It was written by Richard Stallman by simplifying the hairy parser
   used when %semantic_parser is specified.  */
 
+#ifndef YYSTACK_USE_ALLOCA
+#ifdef alloca
+#define YYSTACK_USE_ALLOCA
+#else /* alloca not defined */
+#ifdef __GNUC__
+#define YYSTACK_USE_ALLOCA
+#define alloca __builtin_alloca
+#else /* not GNU C.  */
+#if (!defined (__STDC__) && defined (sparc)) || defined (__sparc__) || defined (__sparc) || defined (__sgi) || (defined (__sun) && defined (__i386))
+#define YYSTACK_USE_ALLOCA
+#include <alloca.h>
+#else /* not sparc */
+/* We think this test detects Watcom and Microsoft C.  */
+/* This used to test MSDOS, but that is a bad idea
+   since that symbol is in the user namespace.  */
+#if (defined (_MSDOS) || defined (_MSDOS_)) && !defined (__TURBOC__)
+#if 0 /* No need for malloc.h, which pollutes the namespace;
+	 instead, just don't use alloca.  */
+#include <malloc.h>
+#endif
+#else /* not MSDOS, or __TURBOC__ */
+#if defined(_AIX)
+/* I don't know what this was needed for, but it pollutes the namespace.
+   So I turned it off.   rms, 2 May 1997.  */
+/* #include <malloc.h>  */
+ #pragma alloca
+#define YYSTACK_USE_ALLOCA
+#else /* not MSDOS, or __TURBOC__, or _AIX */
+#if 0
+#ifdef __hpux /* haible@ilog.fr says this works for HPUX 9.05 and up,
+		 and on HPUX 10.  Eventually we can turn this on.  */
+#define YYSTACK_USE_ALLOCA
+#define alloca __builtin_alloca
+#endif /* __hpux */
+#endif
+#endif /* not _AIX */
+#endif /* not MSDOS, or __TURBOC__ */
+#endif /* not sparc */
+#endif /* not GNU C */
+#endif /* alloca not defined */
+#endif /* YYSTACK_USE_ALLOCA not defined */
+
+#ifdef YYSTACK_USE_ALLOCA
+#define YYSTACK_ALLOC alloca
+#else
+#define YYSTACK_ALLOC malloc
+#endif
+
 /* Note: there must be only one dollar sign in this file.
    It is replaced by the list of actions, each action
    as one case of the switch.  */
@@ -402,8 +422,8 @@ void *alloca ();
 #define yyclearin	(yychar = YYEMPTY)
 #define YYEMPTY		-2
 #define YYEOF		0
-#define YYACCEPT	return(0)
-#define YYABORT 	return(1)
+#define YYACCEPT	goto yyacceptlab
+#define YYABORT 	goto yyabortlab
 #define YYERROR		goto yyerrlab1
 /* Like YYERROR except do call yyerror.
    This remains here temporarily to ease the
@@ -484,12 +504,12 @@ int yydebug;			/*  nonzero means print parse trace	*/
 #ifndef YYMAXDEPTH
 #define YYMAXDEPTH 10000
 #endif
-
-/* Prevent warning if -Wstrict-prototypes.  */
-#ifdef __GNUC__
-int yyparse (void);
-#endif
 
+/* Define __yy_memcpy.  Note that the size argument
+   should be passed with type unsigned int, because that is what the non-GCC
+   definitions require.  With GCC, __builtin_memcpy takes an arg
+   of type size_t, but it can handle unsigned int.  */
+
 #if __GNUC__ > 1		/* GNU C and GNU C++ define this.  */
 #define __yy_memcpy(TO,FROM,COUNT)	__builtin_memcpy(TO,FROM,COUNT)
 #else				/* not GNU C or C++ */
@@ -501,7 +521,7 @@ static void
 __yy_memcpy (to, from, count)
      char *to;
      char *from;
-     int count;
+     unsigned int count;
 {
   register char *f = from;
   register char *t = to;
@@ -516,10 +536,10 @@ __yy_memcpy (to, from, count)
 /* This is the most reliable way to avoid incompatibilities
    in available built-in functions on various systems.  */
 static void
-__yy_memcpy (char *to, char *from, int count)
+__yy_memcpy (char *to, char *from, unsigned int count)
 {
-  register char *f = from;
   register char *t = to;
+  register char *f = from;
   register int i = count;
 
   while (i-- > 0)
@@ -529,7 +549,7 @@ __yy_memcpy (char *to, char *from, int count)
 #endif
 #endif
 
-#line 196 "/usr/lib/bison.simple"
+#line 217 "/usr/share/misc/bison.simple"
 
 /* The user can define YYPARSE_PARAM as the name of an argument to be passed
    into yyparse.  The argument should have type void *.
@@ -550,6 +570,15 @@ __yy_memcpy (char *to, char *from, int count)
 #define YYPARSE_PARAM_DECL
 #endif /* not YYPARSE_PARAM */
 
+/* Prevent warning if -Wstrict-prototypes.  */
+#ifdef __GNUC__
+#ifdef YYPARSE_PARAM
+int yyparse (void *);
+#else
+int yyparse (void);
+#endif
+#endif
+
 int
 yyparse(YYPARSE_PARAM_ARG)
      YYPARSE_PARAM_DECL
@@ -578,6 +607,7 @@ yyparse(YYPARSE_PARAM_ARG)
 #endif
 
   int yystacksize = YYINITDEPTH;
+  int yyfree_stacks = 0;
 
 #ifdef YYPURE
   int yychar;
@@ -662,18 +692,32 @@ yynewstate:
       if (yystacksize >= YYMAXDEPTH)
 	{
 	  yyerror("parser stack overflow");
+	  if (yyfree_stacks)
+	    {
+	      free (yyss);
+	      free (yyvs);
+#ifdef YYLSP_NEEDED
+	      free (yyls);
+#endif
+	    }
 	  return 2;
 	}
       yystacksize *= 2;
       if (yystacksize > YYMAXDEPTH)
 	yystacksize = YYMAXDEPTH;
-      yyss = (short *) alloca (yystacksize * sizeof (*yyssp));
-      __yy_memcpy ((char *)yyss, (char *)yyss1, size * sizeof (*yyssp));
-      yyvs = (YYSTYPE *) alloca (yystacksize * sizeof (*yyvsp));
-      __yy_memcpy ((char *)yyvs, (char *)yyvs1, size * sizeof (*yyvsp));
+#ifndef YYSTACK_USE_ALLOCA
+      yyfree_stacks = 1;
+#endif
+      yyss = (short *) YYSTACK_ALLOC (yystacksize * sizeof (*yyssp));
+      __yy_memcpy ((char *)yyss, (char *)yyss1,
+		   size * (unsigned int) sizeof (*yyssp));
+      yyvs = (YYSTYPE *) YYSTACK_ALLOC (yystacksize * sizeof (*yyvsp));
+      __yy_memcpy ((char *)yyvs, (char *)yyvs1,
+		   size * (unsigned int) sizeof (*yyvsp));
 #ifdef YYLSP_NEEDED
-      yyls = (YYLTYPE *) alloca (yystacksize * sizeof (*yylsp));
-      __yy_memcpy ((char *)yyls, (char *)yyls1, size * sizeof (*yylsp));
+      yyls = (YYLTYPE *) YYSTACK_ALLOC (yystacksize * sizeof (*yylsp));
+      __yy_memcpy ((char *)yyls, (char *)yyls1,
+		   size * (unsigned int) sizeof (*yylsp));
 #endif
 #endif /* no yyoverflow */
 
@@ -842,7 +886,7 @@ case 4:
 case 5:
 #line 162 "nlmheader.y"
 {
-	    nlmheader_warn ("CODESTART is not implemented; sorry", -1);
+	    nlmheader_warn (_("CODESTART is not implemented; sorry"), -1);
 	    free (yyvsp[0].string);
 	  ;
     break;}
@@ -855,7 +899,7 @@ case 6:
 	    len = strlen (yyvsp[0].string);
 	    if (len >= NLM_MAX_COPYRIGHT_MESSAGE_LENGTH)
 	      {
-		nlmheader_warn ("copyright string is too long",
+		nlmheader_warn (_("copyright string is too long"),
 				NLM_MAX_COPYRIGHT_MESSAGE_LENGTH - 1);
 		len = NLM_MAX_COPYRIGHT_MESSAGE_LENGTH - 1;
 	      }
@@ -884,11 +928,11 @@ case 8:
 	    free (yyvsp[-1].string);
 	    free (yyvsp[0].string);
 	    if (version_hdr->month < 1 || version_hdr->month > 12)
-	      nlmheader_warn ("illegal month", -1);
+	      nlmheader_warn (_("illegal month"), -1);
 	    if (version_hdr->day < 1 || version_hdr->day > 31)
-	      nlmheader_warn ("illegal day", -1);
+	      nlmheader_warn (_("illegal day"), -1);
 	    if (version_hdr->year < 1900 || version_hdr->year > 3000)
-	      nlmheader_warn ("illegal year", -1);
+	      nlmheader_warn (_("illegal year"), -1);
 	  ;
     break;}
 case 9:
@@ -905,7 +949,7 @@ case 10:
 	    len = strlen (yyvsp[0].string);
 	    if (len > NLM_MAX_DESCRIPTION_LENGTH)
 	      {
-		nlmheader_warn ("description string is too long",
+		nlmheader_warn (_("description string is too long"),
 				NLM_MAX_DESCRIPTION_LENGTH);
 		len = NLM_MAX_DESCRIPTION_LENGTH;
 	      }
@@ -1027,7 +1071,7 @@ case 28:
 	    if (output_file == NULL)
 	      output_file = yyvsp[0].string;
 	    else
-	      nlmheader_warn ("ignoring duplicate OUTPUT statement", -1);
+	      nlmheader_warn (_("ignoring duplicate OUTPUT statement"), -1);
 	  ;
     break;}
 case 29:
@@ -1050,7 +1094,7 @@ case 31:
 	    len = strlen (yyvsp[0].string);
 	    if (len >= NLM_MAX_SCREEN_NAME_LENGTH)
 	      {
-		nlmheader_warn ("screen name is too long",
+		nlmheader_warn (_("screen name is too long"),
 				NLM_MAX_SCREEN_NAME_LENGTH);
 		len = NLM_MAX_SCREEN_NAME_LENGTH;
 	      }
@@ -1093,7 +1137,7 @@ case 36:
 	    len = strlen (yyvsp[0].string);
 	    if (len >= NLM_MAX_THREAD_NAME_LENGTH)
 	      {
-		nlmheader_warn ("thread name is too long",
+		nlmheader_warn (_("thread name is too long"),
 				NLM_MAX_THREAD_NAME_LENGTH);
 		len = NLM_MAX_THREAD_NAME_LENGTH;
 	      }
@@ -1125,13 +1169,13 @@ case 39:
 	    version_hdr->majorVersion = nlmlex_get_number (yyvsp[-2].string);
 	    val = nlmlex_get_number (yyvsp[-1].string);
 	    if (val < 0 || val > 99)
-	      nlmheader_warn ("illegal minor version number (must be between 0 and 99)",
+	      nlmheader_warn (_("illegal minor version number (must be between 0 and 99)"),
 			      -1);
 	    else
 	      version_hdr->minorVersion = val;
 	    val = nlmlex_get_number (yyvsp[0].string);
 	    if (val < 0)
-	      nlmheader_warn ("illegal revision number (must be between 0 and 26)",
+	      nlmheader_warn (_("illegal revision number (must be between 0 and 26)"),
 			      -1);
 	    else if (val > 26)
 	      version_hdr->revision = 0;
@@ -1151,7 +1195,7 @@ case 40:
 	    version_hdr->majorVersion = nlmlex_get_number (yyvsp[-1].string);
 	    val = nlmlex_get_number (yyvsp[0].string);
 	    if (val < 0 || val > 99)
-	      nlmheader_warn ("illegal minor version number (must be between 0 and 99)",
+	      nlmheader_warn (_("illegal minor version number (must be between 0 and 99)"),
 			      -1);
 	    else
 	      version_hdr->minorVersion = val;
@@ -1237,7 +1281,7 @@ case 51:
     break;}
 }
    /* the action file gets copied in in place of this dollarsign */
-#line 498 "/usr/lib/bison.simple"
+#line 543 "/usr/share/misc/bison.simple"
 
   yyvsp -= yylen;
   yyssp -= yylen;
@@ -1432,6 +1476,30 @@ yyerrhandle:
 
   yystate = yyn;
   goto yynewstate;
+
+ yyacceptlab:
+  /* YYACCEPT comes here.  */
+  if (yyfree_stacks)
+    {
+      free (yyss);
+      free (yyvs);
+#ifdef YYLSP_NEEDED
+      free (yyls);
+#endif
+    }
+  return 0;
+
+ yyabortlab:
+  /* YYABORT comes here.  */
+  if (yyfree_stacks)
+    {
+      free (yyss);
+      free (yyvs);
+#ifdef YYLSP_NEEDED
+      free (yyls);
+#endif
+    }
+  return 1;
 }
 #line 492 "nlmheader.y"
 
@@ -1713,7 +1781,7 @@ tail_recurse:
       if (c != EOF && ! isspace ((unsigned char) c) && c != ',')
 	{
 	  nlmheader_identify ();
-	  fprintf (stderr, "%s:%d: illegal character in keyword: %c\n",
+	  fprintf (stderr, _("%s:%d: illegal character in keyword: %c\n"),
 		   current.name, current.lineno, c);
 	}
       else
@@ -1734,7 +1802,7 @@ tail_recurse:
 	    }
 	  
 	  nlmheader_identify ();
-	  fprintf (stderr, "%s:%d: unrecognized keyword: %s\n",
+	  fprintf (stderr, _("%s:%d: unrecognized keyword: %s\n"),
 		   current.name, current.lineno, lex_buf);
 	}
 
@@ -1771,7 +1839,7 @@ tail_recurse:
       if (c == EOF)
 	{
 	  nlmheader_identify ();
-	  fprintf (stderr, "%s:%d: end of file in quoted string\n",
+	  fprintf (stderr, _("%s:%d: end of file in quoted string\n"),
 		   current.name, start_lineno);
 	  ++parse_errors;
 	}
@@ -1812,7 +1880,7 @@ nlmlex_get_number (s)
 
   ret = strtol (s, &send, 10);
   if (*send != '\0')
-    nlmheader_warn ("bad number", -1);
+    nlmheader_warn (_("bad number"), -1);
   return ret;
 }
 
@@ -1828,7 +1896,7 @@ nlmheader_identify ()
 
   if (! done)
     {
-      fprintf (stderr, "%s: problems in NLM command language input:\n",
+      fprintf (stderr, _("%s: problems in NLM command language input:\n"),
 	       program_name);
       done = 1;
     }
