@@ -256,13 +256,11 @@ static bfd *lineno_cache_bfd;
 static bfd *lineno_cache_rel_bfd;
 
 #define OPTION_TARGET 200
-#define OPTION_DEMANGLER (OPTION_TARGET + 1)
 
 static struct option long_options[] =
 {
   {"debug-syms", no_argument, &print_debug_syms, 1},
   {"demangle", optional_argument, 0, 'C'},
-  {"demangler", required_argument, NULL, OPTION_DEMANGLER},
   {"dynamic", no_argument, &dynamic, 1},
   {"extern-only", no_argument, &external_only, 1},
   {"format", required_argument, 0, 'f'},
@@ -299,11 +297,10 @@ usage (stream, status)
   -a, --debug-syms       Display debugger-only symbols\n\
   -A, --print-file-name  Print name of the input file before every symbol\n\
   -B                     Same as --format=bsd\n\
-  -C, --demangle[=%s]\n\
-                         Decode low-level symbol names into user-level names\n\
+  -C, --demangle[=STYLE] Decode low-level symbol names into user-level names\n\
+                          The STYLE, if specified, can be `auto' (the default),\n\
+                          `gnu', 'lucid', 'arm', 'hp', 'edg' or 'gnu-new-abi'\n\
       --no-demangle      Do not demangle low-level symbol names\n\
-      --demangler=<dso:function>\n\
-			 Set dso and demangler function\n\
   -D, --dynamic          Display dynamic symbols instead of normal symbols\n\
       --defined-only     Display only defined symbols\n\
   -e                     (ignored)\n\
@@ -325,7 +322,7 @@ usage (stream, status)
   -u, --undefined-only   Display only undefined symbols\n\
   -V, --version          Display this program's version number\n\
   -X 32_64               (ignored)\n\
-\n"), get_demangler_list ());
+\n"));
   list_supported_targets (program_name, stream);
   if (status == 0)
     fprintf (stream, _("Report bugs to %s.\n"), REPORT_BUGS_TO);
@@ -398,7 +395,6 @@ main (argc, argv)
 {
   int c;
   int retval;
-  const char *demangler = NULL, *style = NULL;
 
 #if defined (HAVE_SETLOCALE) && defined (HAVE_LC_MESSAGES)
   setlocale (LC_MESSAGES, "");
@@ -432,7 +428,16 @@ main (argc, argv)
 	case 'C':
 	  do_demangle = 1;
 	  if (optarg != NULL)
-	    style = optarg;
+	    {
+	      enum demangling_styles style;
+	      
+	      style = cplus_demangle_name_to_style (optarg);
+	      if (style == unknown_demangling) 
+		fatal (_("unknown demangling style `%s'"),
+		       optarg);
+	      
+	      cplus_demangle_set_style (style);
+           }
 	  break;
 	case 'D':
 	  dynamic = 1;
@@ -492,10 +497,6 @@ main (argc, argv)
 	  target = optarg;
 	  break;
 
-	case OPTION_DEMANGLER:
-	  demangler = optarg;
-	  break;
-
 	case 0:		/* A long option that just sets a flag.  */
 	  break;
 
@@ -504,8 +505,6 @@ main (argc, argv)
 	}
     }
 
-  init_demangler (style, NULL, demangler);
-
   if (show_version)
     print_version ("nm");
 
@@ -1082,7 +1081,7 @@ print_symname (format, name, abfd)
       if (bfd_get_symbol_leading_char (abfd) == name[0])
 	name++;
 
-      res = demangle_symbol (name);
+      res = cplus_demangle (name, DMGL_ANSI | DMGL_PARAMS);
       if (res)
 	{
 	  printf (format, res);
