@@ -1,6 +1,5 @@
 /* This file is obj-ieee.h
-
-   Copyright (C) 1987-1992 Free Software Foundation, Inc.
+   Copyright (C) 1987-1992, 2000 Free Software Foundation, Inc.
 
    This file is part of GAS, the GNU Assembler.
 
@@ -15,8 +14,9 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with GAS; see the file COPYING.  If not, write to
-   the Free Software Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   along with GAS; see the file COPYING.  If not, write to the Free
+   Software Foundation, 59 Temple Place - Suite 330, Boston, MA
+   02111-1307, USA.  */
 
 #define BFD 1
 
@@ -41,10 +41,6 @@ object_headers;
 
 #define DEFAULT_MAGIC_NUMBER_FOR_OBJECT_FILE 1
 
-
 int lineno_rootP;
 
-
 #define IEEE_STYLE
-
-/* end of obj-ieee.h */
