@@ -208,8 +208,7 @@ const relax_typeS md_relax_table[] =
 };
 
 long
-fr30_relax_frag (segment, fragP, stretch)
-     segT    segment;
+fr30_relax_frag (fragP, stretch)
      fragS * fragP;
      long    stretch;
 {
@@ -236,7 +235,7 @@ fr30_relax_frag (segment, fragP, stretch)
     }
   else
     {
-      growth = relax_frag (segment, fragP, stretch);
+      growth = relax_frag (fragP, stretch);
 
       /* Long jump on odd halfword boundary?  */
       if (fragP->fr_subtype == 2 && (address & 3) != 0)
