@@ -1,5 +1,5 @@
 /* tc-m32r.c -- Assembler for the Mitsubishi M32R.
-   Copyright (C) 1996, 1997, 1998, 1999, 2000
+   Copyright (C) 1996, 1997, 1998, 1999, 2000, 2001
    Free Software Foundation, Inc.
 
    This file is part of GAS, the GNU Assembler.
@@ -444,7 +444,7 @@ expand_debug_syms (syms, align)
   if (!syms)
     return;
 
-  (void) m32r_do_align (align, NULL, 0, 0);
+  (void) frag_align_code (align, 0);
   for (; syms != (sym_linkS *) 0; syms = next_syms)
     {
       symbolS *symbolP = syms->symbol;
@@ -1384,8 +1384,7 @@ const relax_typeS md_relax_table[] =
 };
 
 long
-m32r_relax_frag (segment, fragP, stretch)
-     segT segment;
+m32r_relax_frag (fragP, stretch)
      fragS *fragP;
      long stretch;
 {
@@ -1412,7 +1411,7 @@ m32r_relax_frag (segment, fragP, stretch)
     }
   else
     {
-      growth = relax_frag (segment, fragP, stretch);
+      growth = relax_frag (fragP, stretch);
 
       /* Long jump on odd halfword boundary?  */
       if (fragP->fr_subtype == 2 && (address & 3) != 0)
