@@ -1,6 +1,5 @@
 /* tc-mn10200.c -- Assembler code for the Matsushita 10200
-
-   Copyright (C) 1996, 1997 Free Software Foundation.
+   Copyright (C) 1996, 1997, 1998, 1999 Free Software Foundation.
 
    This file is part of GAS, the GNU Assembler.
 
@@ -22,7 +21,7 @@
 #include <stdio.h>
 #include <ctype.h>
 #include "as.h"
-#include "subsegs.h"     
+#include "subsegs.h"
 #include "opcode/mn10200.h"
 
 /* Structure to hold information about predefined registers.  */
@@ -32,46 +31,47 @@ struct reg_name
   int value;
 };
 
-/* Generic assembler global variables which must be defined by all targets. */
+/* Generic assembler global variables which must be defined by all
+   targets.  */
 
-/* Characters which always start a comment. */
+/* Characters which always start a comment.  */
 const char comment_chars[] = "#";
 
 /* Characters which start a comment at the beginning of a line.  */
 const char line_comment_chars[] = ";#";
 
-/* Characters which may be used to separate multiple commands on a 
+/* Characters which may be used to separate multiple commands on a
    single line.  */
 const char line_separator_chars[] = ";";
 
-/* Characters which are used to indicate an exponent in a floating 
+/* Characters which are used to indicate an exponent in a floating
    point number.  */
 const char EXP_CHARS[] = "eE";
 
-/* Characters which mean that a number is a floating point constant, 
+/* Characters which mean that a number is a floating point constant,
    as in 0d1.0.  */
 const char FLT_CHARS[] = "dD";
 
-
 const relax_typeS md_relax_table[] = {
-  /* bCC relaxing */
+  /* bCC relaxing  */
   {0x81, -0x7e, 2, 1},
   {0x8004, -0x7ffb, 5, 2},
   {0x800006, -0x7ffff9, 7, 0},
-  /* bCCx relaxing */
+  /* bCCx relaxing  */
   {0x81, -0x7e, 3, 4},
   {0x8004, -0x7ffb, 6, 5},
   {0x800006, -0x7ffff9, 8, 0},
-  /* jsr relaxing */
+  /* jsr relaxing  */
   {0x8004, -0x7ffb, 3, 7},
   {0x800006, -0x7ffff9, 5, 0},
-  /* jmp relaxing */
+  /* jmp relaxing  */
   {0x81, -0x7e, 2, 9},
   {0x8004, -0x7ffb, 3, 10},
   {0x800006, -0x7ffff9, 5, 0},
 
 };
-/* local functions */
+
+/* Local functions.  */
 static void mn10200_insert_operand PARAMS ((unsigned long *, unsigned long *,
 					    const struct mn10200_operand *,
 					    offsetT, char *, unsigned,
@@ -84,8 +84,7 @@ static boolean data_register_name PARAMS ((expressionS *expressionP));
 static boolean address_register_name PARAMS ((expressionS *expressionP));
 static boolean other_register_name PARAMS ((expressionS *expressionP));
 
-
-/* fixups */
+/* Fixups.  */
 #define MAX_INSN_FIXUPS (5)
 struct mn10200_fixup
 {
@@ -100,7 +99,7 @@ const char *md_shortopts = "";
 struct option md_longopts[] = {
   {NULL, no_argument, NULL, 0}
 };
-size_t md_longopts_size = sizeof(md_longopts); 
+size_t md_longopts_size = sizeof (md_longopts);
 
 /* The target specific pseudo-ops which we support.  */
 const pseudo_typeS md_pseudo_table[] =
@@ -111,7 +110,7 @@ const pseudo_typeS md_pseudo_table[] =
 /* Opcode hash table.  */
 static struct hash_control *mn10200_hash;
 
-/* This table is sorted. Suitable for searching by a binary search. */
+/* This table is sorted. Suitable for searching by a binary search.  */
 static const struct reg_name data_registers[] =
 {
   { "d0", 0 },
@@ -119,7 +118,8 @@ static const struct reg_name data_registers[] =
   { "d2", 2 },
   { "d3", 3 },
 };
-#define DATA_REG_NAME_CNT	(sizeof(data_registers) / sizeof(struct reg_name))
+#define DATA_REG_NAME_CNT				\
+  (sizeof (data_registers) / sizeof (struct reg_name))
 
 static const struct reg_name address_registers[] =
 {
@@ -128,18 +128,20 @@ static const struct reg_name address_registers[] =
   { "a2", 2 },
   { "a3", 3 },
 };
-#define ADDRESS_REG_NAME_CNT	(sizeof(address_registers) / sizeof(struct reg_name))
+#define ADDRESS_REG_NAME_CNT					\
+  (sizeof (address_registers) / sizeof (struct reg_name))
 
 static const struct reg_name other_registers[] =
 {
   { "mdr", 0 },
   { "psw", 0 },
 };
-#define OTHER_REG_NAME_CNT	(sizeof(other_registers) / sizeof(struct reg_name))
+#define OTHER_REG_NAME_CNT				\
+  (sizeof (other_registers) / sizeof (struct reg_name))
 
 /* reg_name_search does a binary search of the given register table
    to see if "name" is a valid regiter name.  Returns the register
-   number from the array on success, or -1 on failure. */
+   number from the array on success, or -1 on failure.  */
 
 static int
 reg_name_search (regs, regcount, name)
@@ -161,14 +163,13 @@ reg_name_search (regs, regcount, name)
 	high = middle - 1;
       else if (cmp > 0)
 	low = middle + 1;
-      else 
-	  return regs[middle].value;
+      else
+	return regs[middle].value;
     }
   while (low <= high);
   return -1;
 }
 
-
 /* Summary of register_name().
  *
  * in: Input_line_pointer points to 1st char of operand.
@@ -179,6 +180,7 @@ reg_name_search (regs, regcount, name)
  *	Input_line_pointer->(next non-blank) char after operand, or is in
  *	its original state.
  */
+
 static boolean
 data_register_name (expressionP)
      expressionS *expressionP;
@@ -188,29 +190,34 @@ data_register_name (expressionP)
   char *start;
   char c;
 
-  /* Find the spelling of the operand */
+  /* Find the spelling of the operand.  */
   start = name = input_line_pointer;
 
   c = get_symbol_end ();
   reg_number = reg_name_search (data_registers, DATA_REG_NAME_CNT, name);
 
-  /* look to see if it's in the register table */
-  if (reg_number >= 0) 
+  /* Look to see if it's in the register table.  */
+  if (reg_number >= 0)
     {
       expressionP->X_op = O_register;
       expressionP->X_add_number = reg_number;
 
-      /* make the rest nice */
+      /* Make the rest nice.  */
       expressionP->X_add_symbol = NULL;
       expressionP->X_op_symbol = NULL;
-      *input_line_pointer = c;	/* put back the delimiting char */
+
+      /* Put back the delimiting char.  */
+      *input_line_pointer = c;
       return true;
     }
   else
     {
-      /* reset the line as if we had not done anything */
-      *input_line_pointer = c;   /* put back the delimiting char */
-      input_line_pointer = start; /* reset input_line pointer */
+      /* Reset the line as if we had not done anything.  */
+      /* Put back the delimiting char.  */
+      *input_line_pointer = c;
+
+      /* Reset input_line pointer.  */
+      input_line_pointer = start;
       return false;
     }
 }
@@ -225,6 +232,7 @@ data_register_name (expressionP)
  *	Input_line_pointer->(next non-blank) char after operand, or is in
  *	its original state.
  */
+
 static boolean
 address_register_name (expressionP)
      expressionS *expressionP;
@@ -234,29 +242,34 @@ address_register_name (expressionP)
   char *start;
   char c;
 
-  /* Find the spelling of the operand */
+  /* Find the spelling of the operand.  */
   start = name = input_line_pointer;
 
   c = get_symbol_end ();
   reg_number = reg_name_search (address_registers, ADDRESS_REG_NAME_CNT, name);
 
-  /* look to see if it's in the register table */
-  if (reg_number >= 0) 
+  /* Look to see if it's in the register table.  */
+  if (reg_number >= 0)
     {
       expressionP->X_op = O_register;
       expressionP->X_add_number = reg_number;
 
-      /* make the rest nice */
+      /* Make the rest nice.  */
       expressionP->X_add_symbol = NULL;
       expressionP->X_op_symbol = NULL;
-      *input_line_pointer = c;	/* put back the delimiting char */
+
+      /* Put back the delimiting char.  */
+      *input_line_pointer = c;
       return true;
     }
   else
     {
-      /* reset the line as if we had not done anything */
-      *input_line_pointer = c;   /* put back the delimiting char */
-      input_line_pointer = start; /* reset input_line pointer */
+      /* Reset the line as if we had not done anything.  */
+      /* Put back the delimiting char.  */
+      *input_line_pointer = c;
+
+      /* Reset input_line pointer.  */
+      input_line_pointer = start;
       return false;
     }
 }
@@ -271,6 +284,7 @@ address_register_name (expressionP)
  *	Input_line_pointer->(next non-blank) char after operand, or is in
  *	its original state.
  */
+
 static boolean
 other_register_name (expressionP)
      expressionS *expressionP;
@@ -280,40 +294,45 @@ other_register_name (expressionP)
   char *start;
   char c;
 
-  /* Find the spelling of the operand */
+  /* Find the spelling of the operand.  */
   start = name = input_line_pointer;
 
   c = get_symbol_end ();
   reg_number = reg_name_search (other_registers, OTHER_REG_NAME_CNT, name);
 
-  /* look to see if it's in the register table */
-  if (reg_number >= 0) 
+  /* Look to see if it's in the register table.  */
+  if (reg_number >= 0)
     {
       expressionP->X_op = O_register;
       expressionP->X_add_number = reg_number;
 
-      /* make the rest nice */
+      /* Make the rest nice.  */
       expressionP->X_add_symbol = NULL;
       expressionP->X_op_symbol = NULL;
-      *input_line_pointer = c;	/* put back the delimiting char */
+
+      /* Put back the delimiting char.  */
+      *input_line_pointer = c;
       return true;
     }
   else
     {
-      /* reset the line as if we had not done anything */
-      *input_line_pointer = c;   /* put back the delimiting char */
-      input_line_pointer = start; /* reset input_line pointer */
+      /* Reset the line as if we had not done anything.  */
+      /* Put back the delimiting char.  */
+      *input_line_pointer = c;
+
+      /* Reset input_line pointer.  */
+      input_line_pointer = start;
       return false;
     }
 }
 
 void
 md_show_usage (stream)
-  FILE *stream;
+     FILE *stream;
 {
-  fprintf(stream, "MN10200 options:\n\
-none yet\n");
-} 
+  fprintf (stream, _("MN10200 options:\n\
+none yet\n"));
+}
 
 int
 md_parse_option (c, arg)
@@ -325,16 +344,16 @@ md_parse_option (c, arg)
 
 symbolS *
 md_undefined_symbol (name)
-  char *name;
+     char *name;
 {
   return 0;
 }
 
 char *
 md_atof (type, litp, sizep)
-  int type;
-  char *litp;
-  int *sizep;
+     int type;
+     char *litp;
+     int *sizep;
 {
   int prec;
   LITTLENUM_TYPE words[4];
@@ -353,9 +372,9 @@ md_atof (type, litp, sizep)
 
     default:
       *sizep = 0;
-      return "bad call to md_atof";
+      return _("bad call to md_atof");
     }
-  
+
   t = atof_ieee (input_line_pointer, type, words);
   if (t)
     input_line_pointer = t;
@@ -371,12 +390,11 @@ md_atof (type, litp, sizep)
   return NULL;
 }
 
-
 void
 md_convert_frag (abfd, sec, fragP)
-  bfd *abfd;
-  asection *sec;
-  fragS *fragP;
+     bfd *abfd;
+     asection *sec;
+     fragS *fragP;
 {
   static unsigned long label_count = 0;
   char buf[40];
@@ -738,7 +756,7 @@ md_begin ()
   char *prev_name = "";
   register const struct mn10200_opcode *op;
 
-  mn10200_hash = hash_new();
+  mn10200_hash = hash_new ();
 
   /* Insert unique names into hash table.  The MN10200 instruction set
      has many identical opcode names that have different opcodes based
@@ -748,7 +766,7 @@ md_begin ()
   op = mn10200_opcodes;
   while (op->name)
     {
-      if (strcmp (prev_name, op->name)) 
+      if (strcmp (prev_name, op->name))
 	{
 	  prev_name = (char *) op->name;
 	  hash_insert (mn10200_hash, op->name, (char *) op);
@@ -763,7 +781,7 @@ md_begin ()
 }
 
 void
-md_assemble (str) 
+md_assemble (str)
      char *str;
 {
   char *s;
@@ -777,16 +795,16 @@ md_assemble (str)
   int match;
 
   /* Get the opcode.  */
-  for (s = str; *s != '\0' && ! isspace (*s); s++)
+  for (s = str; *s != '\0' && !isspace (*s); s++)
     ;
   if (*s != '\0')
     *s++ = '\0';
 
-  /* find the first opcode with the proper name */
-  opcode = (struct mn10200_opcode *)hash_find (mn10200_hash, str);
+  /* Find the first opcode with the proper name.  */
+  opcode = (struct mn10200_opcode *) hash_find (mn10200_hash, str);
   if (opcode == NULL)
     {
-      as_bad ("Unrecognized opcode: `%s'", str);
+      as_bad (_("Unrecognized opcode: `%s'"), str);
       return;
     }
 
@@ -796,7 +814,7 @@ md_assemble (str)
 
   input_line_pointer = str;
 
-  for(;;)
+  for (;;)
     {
       const char *errmsg = NULL;
       int op_idx;
@@ -834,7 +852,7 @@ md_assemble (str)
 	  if (operand->flags & MN10200_OPERAND_RELAX)
 	    relaxable = 1;
 
-	  /* Gather the operand. */
+	  /* Gather the operand.  */
 	  hold = input_line_pointer;
 	  input_line_pointer = str;
 
@@ -927,23 +945,23 @@ md_assemble (str)
 	      expression (&ex);
 	    }
 
-	  switch (ex.X_op) 
+	  switch (ex.X_op)
 	    {
 	    case O_illegal:
-	      errmsg = "illegal operand";
+	      errmsg = _("illegal operand");
 	      goto error;
 	    case O_absent:
-	      errmsg = "missing operand";
+	      errmsg = _("missing operand");
 	      goto error;
 	    case O_register:
 	      if ((operand->flags
-                   & (MN10200_OPERAND_DREG | MN10200_OPERAND_AREG)) == 0)
+		   & (MN10200_OPERAND_DREG | MN10200_OPERAND_AREG)) == 0)
 		{
 		  input_line_pointer = hold;
 		  str = hold;
 		  goto error;
 		}
-		
+
 	      if (opcode->format == FMT_2 || opcode->format == FMT_5)
 		extra_shift = 8;
 	      else if (opcode->format == FMT_3 || opcode->format == FMT_6
@@ -951,7 +969,7 @@ md_assemble (str)
 		extra_shift = 16;
 	      else
 		extra_shift = 0;
-	      
+
 	      mn10200_insert_operand (&insn, &extension, operand,
 				      ex.X_add_number, (char *) NULL,
 				      0, extra_shift);
@@ -964,7 +982,7 @@ md_assemble (str)
 		 then promote it (ie this opcode does not match).  */
 	      if (operand->flags
 		  & (MN10200_OPERAND_PROMOTE | MN10200_OPERAND_RELAX)
-		  && ! check_operand (insn, operand, ex.X_add_number))
+		  && !check_operand (insn, operand, ex.X_add_number))
 		{
 		  input_line_pointer = hold;
 		  str = hold;
@@ -988,7 +1006,7 @@ md_assemble (str)
 
 	      /* We need to generate a fixup for this expression.  */
 	      if (fc >= MAX_INSN_FIXUPS)
-		as_fatal ("too many fixups");
+		as_fatal (_("too many fixups"));
 	      fixups[fc].exp = ex;
 	      fixups[fc].opindex = *opindex_ptr;
 	      fixups[fc].reloc = BFD_RELOC_UNUSED;
@@ -1011,25 +1029,25 @@ keep_going:
 
     error:
       if (match == 0)
-        {
+	{
 	  next_opcode = opcode + 1;
-	  if (!strcmp(next_opcode->name, opcode->name))
+	  if (!strcmp (next_opcode->name, opcode->name))
 	    {
 	      opcode = next_opcode;
 	      continue;
 	    }
-	  
+
 	  as_bad ("%s", errmsg);
 	  return;
-        }
+	}
       break;
     }
-      
+
   while (isspace (*str))
     ++str;
 
   if (*str != '\0')
-    as_bad ("junk at end of line: `%s'", str);
+    as_bad (_("junk at end of line: `%s'"), str);
 
   input_line_pointer = str;
 
@@ -1045,23 +1063,35 @@ keep_going:
     size = 5;
   else
     abort ();
-         
+
   /* Write out the instruction.  */
 
   if (relaxable && fc > 0)
     {
       int type;
 
-      /* bCC */
+      /* bCC  */
       if (size == 2 && opcode->opcode != 0xfc0000)
-	type = 0;
-      /* jsr */
+	{
+	  /* Handle bra specially.  Basically treat it like jmp so
+	     that we automatically handle 8, 16 and 32 bit offsets
+	     correctly as well as jumps to an undefined address.
+
+	     It is also important to not treat it like other bCC
+	     instructions since the long forms of bra is different
+	     from other bCC instructions.  */
+	  if (opcode->opcode == 0xea00)
+	    type = 8;
+	  else
+	    type = 0;
+	}
+      /* jsr  */
       else if (size == 3 && opcode->opcode == 0xfd0000)
 	type = 6;
-      /* jmp */
+      /* jmp  */
       else if (size == 3 && opcode->opcode == 0xfc0000)
 	type = 8;
-      /* bCCx */
+      /* bCCx  */
       else
 	type = 3;
 
@@ -1119,25 +1149,27 @@ keep_going:
 	      int offset;
 	      fixS *fixP;
 
-	      reloc_howto = bfd_reloc_type_lookup (stdoutput, fixups[i].reloc);
+	      reloc_howto = bfd_reloc_type_lookup (stdoutput,
+						   fixups[i].reloc);
 
 	      if (!reloc_howto)
-		abort();
-	  
+		abort ();
+
 	      size = bfd_get_reloc_size (reloc_howto);
 
 	      if (size < 1 || size > 4)
-		abort();
+		abort ();
 
 	      offset = 4 - size;
 	      fixP = fix_new_exp (frag_now, f - frag_now->fr_literal + offset,
 				  size,
-				  &fixups[i].exp, 
+				  &fixups[i].exp,
 				  reloc_howto->pc_relative,
 				  fixups[i].reloc);
 
-	      /* PC-relative offsets are from the first byte of the next
-		 instruction, not from the start of the current instruction.  */
+	      /* PC-relative offsets are from the first byte of the
+		 next instruction, not from the start of the current
+		 instruction.  */
 	      if (reloc_howto->pc_relative)
 		fixP->fx_offset += size;
 	    }
@@ -1156,7 +1188,6 @@ keep_going:
 	      /* Is the reloc pc-relative?  */
 	      pcrel = (operand->flags & MN10200_OPERAND_PCREL) != 0;
 
-
 	      /* Choose a proper BFD relocation type.  */
 	      if (pcrel)
 		{
@@ -1181,7 +1212,8 @@ keep_going:
 		    abort ();
 		}
 
-	      /* Convert the size of the reloc into what fix_new_exp wants.  */
+	      /* Convert the size of the reloc into what fix_new_exp
+                 wants.  */
 	      reloc_size = reloc_size / 8;
 	      if (reloc_size == 8)
 		reloc_size = 0;
@@ -1194,8 +1226,9 @@ keep_going:
 				  reloc_size, &fixups[i].exp, pcrel,
 				  ((bfd_reloc_code_real_type) reloc));
 
-	      /* PC-relative offsets are from the first byte of the next
-		 instruction, not from the start of the current instruction.  */
+	      /* PC-relative offsets are from the first byte of the
+		 next instruction, not from the start of the current
+		 instruction.  */
 	      if (pcrel)
 		fixP->fx_offset += size;
 	    }
@@ -1203,10 +1236,9 @@ keep_going:
     }
 }
 
+/* If while processing a fixup, a reloc really needs to be created
+   Then it is done here.  */
 
-/* if while processing a fixup, a reloc really needs to be created */
-/* then it is done here */
-                 
 arelent *
 tc_gen_reloc (seg, fixp)
      asection *seg;
@@ -1219,21 +1251,29 @@ tc_gen_reloc (seg, fixp)
   if (reloc->howto == (reloc_howto_type *) NULL)
     {
       as_bad_where (fixp->fx_file, fixp->fx_line,
-                    "reloc %d not supported by object file format",
-		    (int)fixp->fx_r_type);
+		    _("reloc %d not supported by object file format"),
+		    (int) fixp->fx_r_type);
       return NULL;
     }
   reloc->address = fixp->fx_frag->fr_address + fixp->fx_where;
 
   if (fixp->fx_addsy && fixp->fx_subsy)
     {
+      if ((S_GET_SEGMENT (fixp->fx_addsy) != S_GET_SEGMENT (fixp->fx_subsy))
+	  || S_GET_SEGMENT (fixp->fx_addsy) == undefined_section)
+	{
+	  as_bad_where (fixp->fx_file, fixp->fx_line,
+			"Difference of symbols in different sections is not supported");
+	  return NULL;
+	}
       reloc->sym_ptr_ptr = &bfd_abs_symbol;
       reloc->addend = (S_GET_VALUE (fixp->fx_addsy)
 		       - S_GET_VALUE (fixp->fx_subsy) + fixp->fx_offset);
     }
-  else 
+  else
     {
-      reloc->sym_ptr_ptr = &fixp->fx_addsy->bsym;
+      reloc->sym_ptr_ptr = (asymbol **) xmalloc (sizeof (asymbol *));
+      *reloc->sym_ptr_ptr = symbol_get_bfdsym (fixp->fx_addsy);
       reloc->addend = fixp->fx_offset;
     }
   return reloc;
@@ -1267,7 +1307,7 @@ md_estimate_size_before_relax (fragp, seg)
 	}
       return 2;
     }
-} 
+}
 
 long
 md_pcrel_from (fixp)
@@ -1275,7 +1315,7 @@ md_pcrel_from (fixp)
 {
   return fixp->fx_frag->fr_address;
 #if 0
-  if (fixp->fx_addsy != (symbolS *) NULL && ! S_IS_DEFINED (fixp->fx_addsy))
+  if (fixp->fx_addsy != (symbolS *) NULL && !S_IS_DEFINED (fixp->fx_addsy))
     {
       /* The symbol is undefined.  Let the linker figure it out.  */
       return 0;
@@ -1321,18 +1361,17 @@ mn10200_insert_operand (insnp, extensionp, operand, val, file, line, shift)
 	  min = - (1 << (operand->bits - 1));
 	}
       else
-        {
-          max = (1 << operand->bits) - 1;
-          min = 0;
-        }
+	{
+	  max = (1 << operand->bits) - 1;
+	  min = 0;
+	}
 
       test = val;
 
-
       if (test < (offsetT) min || test > (offsetT) max)
         {
           const char *err =
-            "operand out of range (%s not between %ld and %ld)";
+            _("operand out of range (%s not between %ld and %ld)");
           char buf[100];
 
           sprint_value (buf, test);
@@ -1378,14 +1417,13 @@ check_operand (insn, operand, val)
 	  min = - (1 << (operand->bits - 1));
 	}
       else
-        {
-          max = (1 << operand->bits) - 1;
-          min = 0;
-        }
+	{
+	  max = (1 << operand->bits) - 1;
+	  min = 0;
+	}
 
       test = val;
 
-
       if (test < (offsetT) min || test > (offsetT) max)
 	return 0;
       else
