@@ -1,5 +1,5 @@
 /* tc-tic80.c -- Assemble for the TI TMS320C80 (MV)
-   Copyright (C) 1996, 1997, 1998, 1999 Free Software Foundation, Inc.
+   Copyright (C) 1996, 1997, 1998, 1999, 2000 Free Software Foundation, Inc.
 
    This file is part of GAS, the GNU Assembler.
 
@@ -58,8 +58,7 @@ const char FLT_CHARS[] = "fF";
 
 extern void obj_coff_section ();
 
-const pseudo_typeS md_pseudo_table[] =
-{
+const pseudo_typeS md_pseudo_table[] = {
   { "align",	s_align_bytes,		4 },	/* Do byte alignment, default is a 4 byte boundary  */
   { "word",	cons,			4 },	/* FIXME: Should this be machine independent?  */
   { "bss",	s_lcomm_bytes,		1 },
@@ -789,7 +788,7 @@ md_assemble (str)
     str++;
 
   /* Isolate the mnemonic from the rest of the string by finding the first
-     whitespace character and zapping it to a null byte. */
+     whitespace character and zapping it to a null byte.  */
   for (scan = str; *scan != '\000' && !isspace (*scan); scan++)
     ;
 
