@@ -1,5 +1,6 @@
 /* This file is tc-z8k.h
-   Copyright (C) 1987-1992, 93, 95, 1997 Free Software Foundation, Inc.
+   Copyright (C) 1987-1992, 93, 95, 97, 98, 2000
+   Free Software Foundation, Inc.
 
    This file is part of GAS, the GNU Assembler.
 
@@ -18,16 +19,21 @@
    Software Foundation, 59 Temple Place - Suite 330, Boston, MA
    02111-1307, USA.  */
 
-
 #define TC_Z8K
 #define TARGET_BYTES_BIG_ENDIAN 1
 
+#if ANSI_PROTOTYPES
+struct internal_reloc;
+#endif
+
+#define WORKING_DOT_WORD
+
 #ifndef BFD_ASSEMBLER
 #define LOCAL_LABEL(x) 0
 #endif
 
 /* This macro translates between an internal fix and an coff reloc type */
-#define TC_COFF_FIX2RTYPE(fixP) abort();
+#define TC_COFF_FIX2RTYPE(fixP) abort ();
 
 #define BFD_ARCH bfd_arch_z8k
 #define COFF_MAGIC 0x8000
@@ -35,6 +41,8 @@
 #define IGNORE_NONSTANDARD_ESCAPES
 
 #define TC_RELOC_MANGLE(s,a,b,c) tc_reloc_mangle(a,b,c)
+extern void tc_reloc_mangle
+  PARAMS ((struct fix *, struct internal_reloc *, bfd_vma));
 
 #define DO_NOT_STRIP 0
 #define LISTING_HEADER "Zilog Z8000 GAS "
@@ -42,5 +50,3 @@
 #define RELOC_32 1234
 
 #define md_operand(x)
-
-/* end of tc-z8k.h */
