@@ -15,7 +15,8 @@
 
    You should have received a copy of the GNU General Public License
    along with GAS; see the file COPYING.  If not, write to
-   the Free Software Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   the Free Software Foundation, 59 Temple Place - Suite 330, Boston, MA
+   02111-1307, USA.  */
 
 /* This header file contains the #defines specific
    to SUN computer SUN 3 series computers.  (The only kind
@@ -24,7 +25,6 @@
    Rumor has it that this file will work on the Sun-2 if the assembler
    is called with -m68010  This is not tested.  */
 
-
 #define TE_SUN3	1
 
 #define LOCAL_LABELS_DOLLAR 1
