@@ -327,7 +327,7 @@ as_bad_internal (file, line, buffer)
    file(s).  Please us when there is no recovery, but we want to
    continue processing but not produce an object file.
    Please explain in string (which may have '\n's) what recovery was
-   done. */
+   done.  */
 
 #ifdef USE_STDARG
 void
@@ -414,6 +414,10 @@ as_fatal (const char *format, ...)
   vfprintf (stderr, format, args);
   (void) putc ('\n', stderr);
   va_end (args);
+  /* Delete the output file, if it exists.  This will prevent make from
+     thinking that a file was created and hence does not need rebuilding.  */
+  if (out_file_name != NULL)
+    unlink (out_file_name);
   xexit (EXIT_FAILURE);
 }
 #else
