@@ -121,7 +121,8 @@ static fragS *chain_frchains_together_1 PARAMS ((segT, struct frchain *));
 #ifdef BFD_ASSEMBLER
 static void chain_frchains_together PARAMS ((bfd *, segT, PTR));
 static void cvt_frag_to_fill PARAMS ((segT, fragS *));
-static void relax_and_size_seg PARAMS ((bfd *, asection *, PTR));
+static void relax_seg PARAMS ((bfd *, asection *, PTR));
+static void size_seg PARAMS ((bfd *, asection *, PTR));
 static void adjust_reloc_syms PARAMS ((bfd *, asection *, PTR));
 static void write_relocs PARAMS ((bfd *, asection *, PTR));
 static void write_contents PARAMS ((bfd *, asection *, PTR));
@@ -593,7 +594,21 @@ cvt_frag_to_fill (headersP, sec, fragP)
 
 #ifdef BFD_ASSEMBLER
 static void
-relax_and_size_seg (abfd, sec, xxx)
+relax_seg (abfd, sec, do_code)
+     bfd *abfd;
+     asection *sec;
+     PTR do_code;
+{
+  flagword flags = bfd_get_section_flags (abfd, sec);
+  segment_info_type *seginfo = seg_info (sec);
+
+  if (!(flags & SEC_CODE) == !do_code
+      && seginfo && seginfo->frchainP)
+    relax_segment (seginfo->frchainP->frch_root, sec);
+}
+
+static void
+size_seg (abfd, sec, xxx)
      bfd *abfd;
      asection *sec;
      PTR xxx ATTRIBUTE_UNUSED;
@@ -606,12 +621,9 @@ relax_and_size_seg (abfd, sec, xxx)
 
   subseg_change (sec, 0);
 
-  flags = bfd_get_section_flags (abfd, sec);
-
   seginfo = seg_info (sec);
   if (seginfo && seginfo->frchainP)
     {
-      relax_segment (seginfo->frchainP->frch_root, sec);
       for (fragp = seginfo->frchainP->frch_root; fragp; fragp = fragp->fr_next)
 	cvt_frag_to_fill (sec, fragp);
       for (fragp = seginfo->frchainP->frch_root;
@@ -624,6 +636,8 @@ relax_and_size_seg (abfd, sec, xxx)
   else
     size = 0;
 
+  flags = bfd_get_section_flags (abfd, sec);
+
   if (size > 0 && ! seginfo->bss)
     flags |= SEC_HAS_CONTENTS;
 
@@ -1514,7 +1528,9 @@ write_object_file ()
 #endif
 
 #ifdef BFD_ASSEMBLER
-  bfd_map_over_sections (stdoutput, relax_and_size_seg, (char *) 0);
+  bfd_map_over_sections (stdoutput, relax_seg, (char *) 1);
+  bfd_map_over_sections (stdoutput, relax_seg, (char *) 0);
+  bfd_map_over_sections (stdoutput, size_seg, (char *) 0);
 #else
   relax_and_size_all_segments ();
 #endif /* BFD_ASSEMBLER  */
@@ -1998,30 +2014,21 @@ write_object_file ()
 static int is_dnrange PARAMS ((fragS *, fragS *));
 
 /* Subroutines of relax_segment.  */
-
 static int
 is_dnrange (f1, f2)
      fragS *f1;
      fragS *f2;
 {
-  addressT f2addr;
-
-  f2addr = f2->fr_address;
   for (; f1; f1 = f1->fr_next)
-    {
-      if (f1->fr_next == f2)
-	return 1;
-      if (f1->fr_address > f2addr)
-	break;
-    }
+    if (f1->fr_next == f2)
+      return 1;
   return 0;
 }
 
 /* Relax a fragment by scanning TC_GENERIC_RELAX_TABLE.  */
 
 long
-relax_frag (segment, fragP, stretch)
-     segT segment;
+relax_frag (fragP, stretch)
      fragS *fragP;
      long stretch;
 {
@@ -2043,10 +2050,6 @@ relax_frag (segment, fragP, stretch)
 
   if (symbolP)
     {
-      fragS *sym_frag;
-
-      sym_frag = symbol_get_frag (symbolP);
-
 #ifndef DIFF_EXPR_OK
 #if !defined (MANY_SEGMENTS) && !defined (BFD_ASSEMBLER)
       know ((S_GET_SEGMENT (symbolP) == SEG_ABSOLUTE)
@@ -2054,24 +2057,23 @@ relax_frag (segment, fragP, stretch)
 	    || (S_GET_SEGMENT (symbolP) == SEG_BSS)
 	    || (S_GET_SEGMENT (symbolP) == SEG_TEXT));
 #endif
-      know (sym_frag != NULL);
+      know (symbolP->sy_frag);
 #endif
       know (!(S_GET_SEGMENT (symbolP) == absolute_section)
-	    || sym_frag == &zero_address_frag);
-      target += S_GET_VALUE (symbolP) + sym_frag->fr_address;
+	    || symbolP->sy_frag == &zero_address_frag);
+      target += S_GET_VALUE (symbolP) + symbol_get_frag (symbolP)->fr_address;
 
       /* If frag has yet to be reached on this pass,
 	 assume it will move by STRETCH just as we did.
 	 If this is not so, it will be because some frag
 	 between grows, and that will force another pass.
 
-	 Beware zero-length frags.  */
+	 Beware zero-length frags.
 
-      if (stretch != 0
-	  && S_GET_SEGMENT (symbolP) == segment
-	  && (sym_frag->fr_address > was_address
-	      || (sym_frag->fr_address == was_address
-		  && is_dnrange (fragP, sym_frag))))
+	 There should be a faster way to do this.  */
+
+      if (symbol_get_frag (symbolP)->fr_address >= was_address
+	  && is_dnrange (fragP, symbol_get_frag (symbolP)))
 	{
 	  target += stretch;
 	}
@@ -2427,12 +2429,12 @@ relax_segment (segment_frag_root, segment)
 
 	      case rs_machine_dependent:
 #ifdef md_relax_frag
-		growth = md_relax_frag (segment, fragP, stretch);
+		growth = md_relax_frag (fragP, stretch);
 #else
 #ifdef TC_GENERIC_RELAX_TABLE
 		/* The default way to relax a frag is to look through
 		   TC_GENERIC_RELAX_TABLE.  */
-		growth = relax_frag (segment, fragP, stretch);
+		growth = relax_frag (fragP, stretch);
 #endif /* TC_GENERIC_RELAX_TABLE  */
 #endif
 		break;
