@@ -80,7 +80,6 @@ static char *default_excluded_list[] =
 
 #define OPTION_DEMANGLE		(150)
 #define OPTION_NO_DEMANGLE	(OPTION_DEMANGLE + 1)
-#define OPTION_DEMANGLER	(OPTION_NO_DEMANGLE + 1)
 
 static struct option long_options[] =
 {
@@ -108,7 +107,6 @@ static struct option long_options[] =
   {"all-lines", no_argument, 0, 'x'},
   {"demangle", optional_argument, 0, OPTION_DEMANGLE},
   {"no-demangle", no_argument, 0, OPTION_NO_DEMANGLE},
-  {"demangler", required_argument, NULL, OPTION_DEMANGLER},
   {"directory-path", required_argument, 0, 'I'},
   {"display-unused-functions", no_argument, 0, 'z'},
   {"min-count", required_argument, 0, 'm'},
@@ -140,6 +138,7 @@ static struct option long_options[] =
   {0, no_argument, 0, 0}
 };
 
+
 static void
 DEFUN (usage, (stream, status), FILE * stream AND int status)
 {
@@ -155,10 +154,9 @@ Usage: %s [-[abcDhilLsTvwxyz]] [-[ACeEfFJnNOpPqQZ][name]] [-I dirs]\n\
 	[--no-static] [--print-path] [--separate-files]\n\
 	[--static-call-graph] [--sum] [--table-length=len] [--traditional]\n\
 	[--version] [--width=n] [--ignore-non-functions]\n\
-	[--demangle[=%s]]\n\
-	[--no-demangle] [--demangler=dso:function]\n\
+	[--demangle[=STYLE]] [--no-demangle]\n\
 	[image-file] [profile-file...]\n"),
-	   whoami, get_demangler_list ());
+	   whoami);
   if (status == 0)
     fprintf (stream, _("Report bugs to %s\n"), REPORT_BUGS_TO);
   done (status);
@@ -171,7 +169,6 @@ DEFUN (main, (argc, argv), int argc AND char **argv)
   char **sp, *str;
   Sym **cg = 0;
   int ch, user_specified = 0;
-  const char *demangler = NULL, *style = NULL;
 
 #if defined (HAVE_SETLOCALE) && defined (HAVE_LC_MESSAGES)
   setlocale (LC_MESSAGES, "");
@@ -430,21 +427,29 @@ This program is free software.  This program has absolutely no warranty.\n"));
 	case OPTION_DEMANGLE:
 	  demangle = TRUE;
 	  if (optarg != NULL)
-	    style = optarg;
+	    {
+	      enum demangling_styles style;
+	      
+	      style = cplus_demangle_name_to_style (optarg);
+	      if (style == unknown_demangling) 
+		{
+		  fprintf (stderr,
+			   _("%s: unknown demangling style `%s'\n"),
+			   whoami, optarg);
+		  xexit (1);
+		}
+	      
+	      cplus_demangle_set_style (style);
+           }
 	  break;
 	case OPTION_NO_DEMANGLE:
 	  demangle = FALSE;
 	  break;
-	case OPTION_DEMANGLER:
-	  demangler = optarg;
-	  break;
 	default:
 	  usage (stderr, 1);
 	}
     }
 
-  init_demangler (style, NULL, demangler);
-
   /* Don't allow both ordering options, they modify the arc data in-place.  */
   if ((user_specified & STYLE_FUNCTION_ORDER)
       && (user_specified & STYLE_FILE_ORDER))
