@@ -16,9 +16,11 @@ struct external_filehdr {
 
 #define	H8300MAGIC	0x8300
 #define	H8300HMAGIC	0x8301
+#define	H8300SMAGIC	0x8302
 
 #define H8300BADMAG(x) (((x).f_magic!=H8300MAGIC))
 #define H8300HBADMAG(x) (((x).f_magic!=H8300HMAGIC))
+#define H8300SBADMAG(x) (((x).f_magic!=H8300SMAGIC))
 
 #define	FILHDR	struct external_filehdr
 #define	FILHSZ	20
