@@ -58,30 +58,27 @@
 #define DISCARD_SECTION_NAME "/DISCARD/"
 
 /* A file name list */
-typedef struct name_list
-{
-   const char *name;
-   struct name_list *next;
-} name_list;
+typedef struct name_list {
+  const char *name;
+  struct name_list *next;
+}
+name_list;
 
 /* A wildcard specification.  This is only used in ldgram.y, but it
    winds up in ldgram.h, so we need to define it outside.  */
 
-struct wildcard_spec
-{
+struct wildcard_spec {
   const char *name;
   struct name_list *exclude_name_list;
   boolean sorted;
 };
 
 /* Extra information we hold on sections */
-typedef struct  user_section_struct
-{
+typedef struct user_section_struct {
   /* Pointer to the section where this data will go */
   struct lang_input_statement_struct *file;
 } section_userdata_type;
 
-
 #define get_userdata(x) ((x)->userdata)
 
 #define BYTE_SIZE	(1)
@@ -97,8 +94,7 @@ typedef struct  user_section_struct
 #define ALIGN_N(this, boundary) \
   ((( (this) + ((boundary) -1)) & (~((boundary)-1))))
 
-typedef struct
-{
+typedef struct {
   /* 1 => assign space to common symbols even if `relocatable_output'.  */
   boolean force_common_definition;
   boolean relax;
@@ -127,7 +123,7 @@ typedef struct
      file.  */
   boolean embedded_relocs;
 
-  /* If true, force generation of a file with a .exe file. */
+  /* If true, force generation of a file with a .exe file.  */
   boolean force_exe_suffix;
 
   /* If true, generate a cross reference report.  */
@@ -156,16 +152,13 @@ typedef struct
      fpor overlaps.  */
   boolean check_section_addresses;
 
-  /* It is used to specify where to find some multilib files. */
-  char *multilib_dir;
 } args_type;
 
 extern args_type command_line;
 
 typedef int token_code_type;
 
-typedef struct 
-{
+typedef struct {
   bfd_size_type specified_data_size;
   boolean magic_demand_paged;
   boolean make_executable;
@@ -208,14 +201,17 @@ typedef struct
 
   boolean stats;
 
-  int split_by_reloc;
-  boolean split_by_file;
+  /* If set, orphan input sections will be mapped to separate output
+     sections.  */
+  boolean unique_orphan_sections;
+
+  unsigned int split_by_reloc;
+  bfd_size_type split_by_file;
 } ld_config_type;
 
 extern ld_config_type config;
 
-typedef enum
-{
+typedef enum {
   lang_first_phase_enum,
   lang_allocating_phase_enum,
   lang_final_phase_enum
