@@ -29,8 +29,7 @@ extern const char *ldfile_output_machine_name;
 /* Structure used to hold the list of directories to search for
    libraries.  */
 
-typedef struct search_dirs 
-{
+typedef struct search_dirs {
   /* Next directory on list.  */
   struct search_dirs *next;
   /* Name of directory.  */
@@ -42,8 +41,7 @@ typedef struct search_dirs
 extern search_dirs_type *search_head;
 
 extern void ldfile_add_arch PARAMS ((CONST char *));
-extern void ldfile_add_library_path
-  PARAMS ((const char *, boolean cmdline, boolean append));
+extern void ldfile_add_library_path PARAMS ((const char *, boolean cmdline));
 extern void ldfile_open_command_file PARAMS ((const char *name));
 extern void ldfile_open_file PARAMS ((struct lang_input_statement_struct *));
 extern boolean ldfile_try_open_bfd
