@@ -92,7 +92,7 @@ args_type command_line;
 ld_config_type config;
 
 static void remove_output PARAMS ((void));
-static boolean check_for_scripts_dir PARAMS ((char *dir, boolean append));
+static boolean check_for_scripts_dir PARAMS ((char *dir));
 static boolean add_archive_element PARAMS ((struct bfd_link_info *, bfd *,
 					    const char *));
 static boolean multiple_definition PARAMS ((struct bfd_link_info *,
@@ -206,7 +206,6 @@ main (argc, argv)
   command_line.rpath = NULL;
   command_line.warn_mismatch = true;
   command_line.check_section_addresses = true;
-  command_line.multilib_dir = NULL;
 
   /* We initialize DEMANGLING based on the environment variable
      COLLECT_NO_DEMANGLE.  The gcc collect2 program will demangle the
@@ -535,9 +534,8 @@ get_emulation (argc, argv)
    else return false.  */
 
 static boolean
-check_for_scripts_dir (dir, append)
+check_for_scripts_dir (dir)
      char *dir;
-     boolean append;
 {
   size_t dirlen;
   char *buf;
@@ -552,7 +550,7 @@ check_for_scripts_dir (dir, append)
   res = stat (buf, &s) == 0 && S_ISDIR (s.st_mode);
   free (buf);
   if (res)
-    ldfile_add_library_path (dir, false, append);
+    ldfile_add_library_path (dir, false);
   return res;
 }
 
@@ -570,29 +568,7 @@ set_scripts_dir ()
   char *end, *dir;
   size_t dirlen;
 
-  if (command_line.multilib_dir != NULL)
-    {
-      if (*command_line.multilib_dir == '/')
-	{
-	  dir = xmalloc (strlen (command_line.multilib_dir) + 1);
-	  strcpy (dir, command_line.multilib_dir);
-	}
-      else
-	{
-	  dir = xmalloc (strlen (SCRIPTDIR)
-			 + strlen (command_line.multilib_dir) + 2);
-	  strcpy (dir, SCRIPTDIR);
-	  strcat (dir, "/");
-	  strcat (dir, command_line.multilib_dir);
-	}
-
-      if (check_for_scripts_dir (dir, false))
-	return;
-      else
-	free (dir);
-    }
-
-  if (check_for_scripts_dir (SCRIPTDIR, true))
+  if (check_for_scripts_dir (SCRIPTDIR))
     /* We've been installed normally.  */
     return;
 
@@ -621,13 +597,13 @@ set_scripts_dir ()
   strncpy (dir, program_name, dirlen);
   dir[dirlen] = '\0';
 
-  if (check_for_scripts_dir (dir, true))
+  if (check_for_scripts_dir (dir))
     /* Don't free dir.  */
     return;
 
   /* Look for "ldscripts" in <the dir where our binary is>/../lib.  */
   strcpy (dir + dirlen, "/../lib");
-  if (check_for_scripts_dir (dir, true))
+  if (check_for_scripts_dir (dir))
     return;
 
   /* Well, we tried.  */
