@@ -76,10 +76,10 @@ demangle (string)
       && bfd_get_symbol_leading_char (output_bfd) == string[0])
     ++string;
 
-  /* This is a hack for better error reporting on XCOFF, or the MS PE   */
-  /* format.  Xcoff has a single '.', while the NT PE for PPC has '..'. */
-  /* So we remove all of them.                                          */
-  while(string[0] == '.')
+  /* This is a hack for better error reporting on XCOFF, or the MS PE
+     format.  Xcoff has a single '.', while the NT PE for PPC has
+     '..'.  So we remove all of them.  */
+  while (string[0] == '.')
     ++string;
 
   res = cplus_demangle (string, DMGL_ANSI | DMGL_PARAMS);
@@ -96,19 +96,19 @@ vfinfo (fp, fmt, arg)
 
   while (*fmt != '\0')
     {
-      while (*fmt != '%' && *fmt != '\0') 
+      while (*fmt != '%' && *fmt != '\0')
 	{
 	  putc (*fmt, fp);
 	  fmt++;
 	}
 
-      if (*fmt == '%') 
+      if (*fmt == '%')
 	{
-	  fmt ++;
-	  switch (*fmt++) 
+	  fmt++;
+	  switch (*fmt++)
 	    {
 	    default:
-	      fprintf (fp,"%%%c", fmt[-1]);
+	      fprintf (fp, "%%%c", fmt[-1]);
 	      break;
 
 	    case '%':
@@ -191,7 +191,7 @@ vfinfo (fp, fmt, arg)
 
 	    case 'B':
 	      /* filename from a bfd */
-	      { 
+	      {
 		bfd *abfd = va_arg (arg, bfd *);
 		if (abfd->my_archive)
 		  fprintf (fp, "%s(%s)", abfd->my_archive->filename,
@@ -202,12 +202,12 @@ vfinfo (fp, fmt, arg)
 	      break;
 
 	    case 'F':
-	      /* error is fatal */
+	      /* Error is fatal.  */
 	      fatal = true;
 	      break;
 
 	    case 'P':
-	      /* print program name */
+	      /* Print program name.  */
 	      fprintf (fp, "%s", program_name);
 	      break;
 
@@ -233,7 +233,7 @@ vfinfo (fp, fmt, arg)
 	      break;
 
 	    case 'S':
-	      /* print script file and linenumber */
+	      /* Print script file and linenumber.  */
 	      if (parsing_defsym)
 		fprintf (fp, "--defsym %s", lex_string);
 	      else if (ldfile_input_filename != NULL)
@@ -243,17 +243,17 @@ vfinfo (fp, fmt, arg)
 	      break;
 
 	    case 'R':
-	      /* Print all that's interesting about a relent */
+	      /* Print all that's interesting about a relent.  */
 	      {
 		arelent *relent = va_arg (arg, arelent *);
-	
+
 		lfinfo (fp, "%s+0x%v (type %s)",
 			(*(relent->sym_ptr_ptr))->name,
 			relent->addend,
 			relent->howto->name);
 	      }
 	      break;
-	
+
 	    case 'C':
 	    case 'D':
 	    case 'G':
@@ -355,7 +355,7 @@ vfinfo (fp, fmt, arg)
 			if (linenumber != 0)
 			  lfinfo (fp, ":%u", linenumber);
 		      }
-		    else if (linenumber != 0) 
+		    else if (linenumber != 0)
 		      lfinfo (fp, "%B:%s:%u", abfd, filename, linenumber);
 		    else
 		      lfinfo (fp, "%B(%s+0x%v):%s", abfd, section->name,
@@ -380,7 +380,7 @@ vfinfo (fp, fmt, arg)
 		  }
 	      }
 	      break;
-		
+
 	    case 's':
 	      /* arbitrary string, like printf */
 	      fprintf (fp, "%s", va_arg (arg, char *));
@@ -399,11 +399,11 @@ vfinfo (fp, fmt, arg)
 	}
     }
 
-  if (fatal == true) 
-    xexit(1);
+  if (fatal == true)
+    xexit (1);
 }
 
-/* Format info message and print on stdout. */
+/* Format info message and print on stdout.  */
 
 /* (You would think this should be called just "info", but then you
    would hosed by LynxOS, which defines that name in its libc.)  */
@@ -431,7 +431,7 @@ info_msg (va_alist)
   va_end (arg);
 }
 
-/* ('e' for error.) Format info message and print on stderr. */
+/* ('e' for error.) Format info message and print on stderr.  */
 
 void
 #if USE_STDARG
@@ -456,7 +456,7 @@ einfo (va_alist)
   va_end (arg);
 }
 
-void 
+void
 info_assert (file, line)
      const char *file;
      unsigned int line;
@@ -468,13 +468,13 @@ char *
 buystring (x)
      CONST char *CONST x;
 {
-  size_t l = strlen(x)+1;
-  char *r = xmalloc(l);
-  memcpy(r, x,l);
+  size_t l = strlen (x) + 1;
+  char *r = xmalloc (l);
+  memcpy (r, x, l);
   return r;
 }
 
-/* ('m' for map) Format info message and print on map. */
+/* ('m' for map) Format info message and print on map.  */
 
 void
 #if USE_STDARG
@@ -525,13 +525,13 @@ lfinfo (va_alist)
 
 /* Functions to print the link map.  */
 
-void 
+void
 print_space ()
 {
   fprintf (config.map_file, " ");
 }
 
-void 
+void
 print_nl ()
 {
   fprintf (config.map_file, "\n");
