@@ -1,5 +1,5 @@
 /* Disassemble MN10300 instructions.
-   Copyright (C) 1996, 1997, 1998 Free Software Foundation, Inc.
+   Copyright (C) 1996, 1997, 1998, 2000 Free Software Foundation, Inc.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -484,6 +484,8 @@ disassemble (memaddr, info, insn, size)
 		  temp = extension >> operand->shift;
 		  temp &= ((1 << (32 - operand->bits)) - 1);
 		  value |= temp;
+		  value = ((value ^ (((unsigned long)1) << 31))
+			   - (((unsigned long)1) << 31));
 		}
 	      else if ((operand->flags & MN10300_OPERAND_24BIT) != 0)
 		{
@@ -494,7 +496,7 @@ disassemble (memaddr, info, insn, size)
 		  temp &= ((1 << (24 - operand->bits)) - 1);
 		  value |= temp;
 		  if ((operand->flags & MN10300_OPERAND_SIGNED) != 0)
-		    value = ((value & 0xffffff) ^ (~0x7fffff)) + 0x800000;
+		    value = ((value & 0xffffff) ^ 0x800000) - 0x800000;
 		}
 	      else if ((operand->flags & MN10300_OPERAND_EXTENDED) != 0)
 		{
@@ -508,11 +510,10 @@ disassemble (memaddr, info, insn, size)
 		}
 
 	      if ((operand->flags & MN10300_OPERAND_SIGNED) != 0
-		   /* These are properly extended by the code above.  */
-		   && ((operand->flags & MN10300_OPERAND_24BIT) == 0)
-		  )
-		value = ((long)(value << (32 - operand->bits))
-			  >> (32 - operand->bits));
+		  /* These are properly extended by the code above.  */
+		  && ((operand->flags & MN10300_OPERAND_24BIT) == 0))
+		value = ((value ^ (((unsigned long)1) << (operand->bits - 1)))
+			 - (((unsigned long)1) << (operand->bits - 1)));
 
 	      if (!nocomma
 		  && (!paren
@@ -525,14 +526,14 @@ disassemble (memaddr, info, insn, size)
 		{
 		  value = ((insn >> (operand->shift + extra_shift))
 			   & ((1 << operand->bits) - 1));
-		  (*info->fprintf_func) (info->stream, "d%d", value);
+		  (*info->fprintf_func) (info->stream, "d%d", (int)value);
 		}
 
 	      else if ((operand->flags & MN10300_OPERAND_AREG) != 0)
 		{
 		  value = ((insn >> (operand->shift + extra_shift))
 			   & ((1 << operand->bits) - 1));
-		  (*info->fprintf_func) (info->stream, "a%d", value);
+		  (*info->fprintf_func) (info->stream, "a%d", (int)value);
 		}
 
 	      else if ((operand->flags & MN10300_OPERAND_SP) != 0)
@@ -549,11 +550,11 @@ disassemble (memaddr, info, insn, size)
 		  value = ((insn >> (operand->shift + extra_shift))
 			   & ((1 << operand->bits) - 1));
 		  if (value < 8)
-		    (*info->fprintf_func) (info->stream, "r%d", value);
+		    (*info->fprintf_func) (info->stream, "r%d", (int)value);
 		  else if (value < 12)
-		    (*info->fprintf_func) (info->stream, "a%d", value - 8);
+		    (*info->fprintf_func) (info->stream, "a%d", (int)value - 8);
 		  else
-		    (*info->fprintf_func) (info->stream, "d%d", value - 12);
+		    (*info->fprintf_func) (info->stream, "d%d", (int)value - 12);
 		}
 
 	      else if ((operand->flags & MN10300_OPERAND_XRREG) != 0)
@@ -563,7 +564,7 @@ disassemble (memaddr, info, insn, size)
 		  if (value == 0)
 		    (*info->fprintf_func) (info->stream, "sp", value);
 		  else
-		  (*info->fprintf_func) (info->stream, "xr%d", value);
+		  (*info->fprintf_func) (info->stream, "xr%d", (int)value);
 		}
 
 	      else if ((operand->flags & MN10300_OPERAND_USP) != 0)
@@ -670,7 +671,7 @@ disassemble (memaddr, info, insn, size)
 		}
 
 	      else 
-		(*info->fprintf_func) (info->stream, "%d", value);
+		(*info->fprintf_func) (info->stream, "%ld", (long)value);
 	    }
 	  /* All done. */
 	  break;
