@@ -1,5 +1,5 @@
 /* Print National Semiconductor 32000 instructions.
-   Copyright 1986, 88, 91, 92, 94, 95, 1998 Free Software Foundation, Inc.
+   Copyright (c) 1986, 88, 91, 92, 94, 95, 1998 Free Software Foundation, Inc.
 
 This file is part of opcodes library.
 
@@ -25,17 +25,17 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 #define const
 #endif
 #include "opcode/ns32k.h"
+#include "opintl.h"
 
 static disassemble_info *dis_info;
 
 /*
  * Hacks to get it to compile <= READ THESE AS FIXES NEEDED
  */
-#define CORE_ADDR unsigned long
 #define INVALID_FLOAT(val, size) invalid_float((char *)val, size)
 
 static int print_insn_arg
-  PARAMS ((int, int, int *, char *, CORE_ADDR, char *, int));
+  PARAMS ((int, int, int *, char *, bfd_vma, char *, int));
 static int get_displacement PARAMS ((char *, int *));
 static int invalid_float PARAMS ((char *, int));
 
@@ -297,6 +297,37 @@ bit_extract (buffer, offset, count)
   return result;
 }
 
+/* Like bit extract but the buffer is valid and doen't need to be
+ * fetched
+ */
+static int
+bit_extract_simple (buffer, offset, count)
+     bfd_byte *buffer;
+     int offset;
+     int count;
+{
+  int result;
+  int mask;
+  int bit;
+
+  buffer += offset >> 3;
+  offset &= 7;
+  bit = 1;
+  result = 0;
+  while (count--)
+    {
+      if ((*buffer & (1 << offset)))
+	result |= bit;
+      if (++offset == 8)
+	{
+	  offset = 0;
+	  buffer++;
+	}
+      bit <<= 1;
+    }
+  return result;
+}
+
 static void
 bit_copy (buffer, offset, count, to)
      char *buffer;
@@ -472,14 +503,14 @@ print_insn_ns32k (memaddr, info)
 	}
       for (argnum = 0; argnum <= maxarg; argnum++)
 	{
-	  CORE_ADDR addr;
+	  bfd_vma addr;
 	  char *ch;
 	  for (ch = arg_bufs[argnum]; *ch;)
 	    {
 	      if (*ch == NEXT_IS_ADDR)
 		{
 		  ++ch;
-		  addr = atoi (ch);
+		  addr = bfd_scan_vma (ch, NULL, 16);
 		  (*dis_info->print_address_func) (addr, dis_info);
 		  while (*ch && *ch != NEXT_IS_ADDR)
 		    ++ch;
@@ -511,7 +542,7 @@ print_insn_arg (d, ioffset, aoffsetp, buffer, addr, result, index_offset)
      int d;
      int ioffset, *aoffsetp;
      char *buffer;
-     CORE_ADDR addr;
+     bfd_vma addr;
      char *result;
      int index_offset;
 {
@@ -584,7 +615,7 @@ print_insn_arg (d, ioffset, aoffsetp, buffer, addr, result, index_offset)
 	       * aoffsetp by since whatever generated this is broken
 	       * anyway!
 	       */
-	      sprintf (result, "$<undefined>");
+	      sprintf (result, _("$<undefined>"));
 	      break;
 	    case 'B':
 	      Ivalue = bit_extract (buffer, *aoffsetp, 8);
@@ -659,7 +690,11 @@ print_insn_arg (d, ioffset, aoffsetp, buffer, addr, result, index_offset)
 	case 0x1b:
 	  /* Memory space disp(PC) */
 	  disp1 = get_displacement (buffer, aoffsetp);
-	  sprintf (result, "|%ld|", addr + disp1);
+	  *result++ = NEXT_IS_ADDR;
+	  sprintf_vma (result, addr + disp1);
+	  result += strlen (result);
+	  *result++ = NEXT_IS_ADDR;
+	  *result = '\0';
 	  break;
 	case 0x1c:
 	case 0x1d:
@@ -717,9 +752,11 @@ print_insn_arg (d, ioffset, aoffsetp, buffer, addr, result, index_offset)
       sprintf (result, "%d", (Ivalue / size) + 1);
       break;
     case 'p':
-      sprintf (result, "%c%ld%c", NEXT_IS_ADDR,
-	       addr + get_displacement (buffer, aoffsetp),
-	       NEXT_IS_ADDR);
+      *result++ = NEXT_IS_ADDR;
+      sprintf_vma (result, addr + get_displacement (buffer, aoffsetp));
+      result += strlen (result);
+      *result++ = NEXT_IS_ADDR;
+      *result = '\0';
       break;
     case 'i':
       Ivalue = bit_extract (buffer, *aoffsetp, 8);
@@ -817,14 +854,14 @@ invalid_float (p, len)
   register int val;
 
   if ( len == 4 )
-    val = (bit_extract(p, 23, 8)/*exponent*/ == 0xff
-	   || (bit_extract(p, 23, 8)/*exponent*/ == 0 &&
-	       bit_extract(p, 0, 23)/*mantisa*/ != 0));
+    val = (bit_extract_simple(p, 23, 8)/*exponent*/ == 0xff
+	   || (bit_extract_simple(p, 23, 8)/*exponent*/ == 0 &&
+	       bit_extract_simple(p, 0, 23)/*mantisa*/ != 0));
   else if ( len == 8 )
-    val = (bit_extract(p, 52, 11)/*exponent*/ == 0x7ff
-	   || (bit_extract(p, 52, 11)/*exponent*/ == 0
-	       && (bit_extract(p, 0, 32)/*low mantisa*/ != 0
-		   || bit_extract(p, 32, 20)/*high mantisa*/ != 0)));
+    val = (bit_extract_simple(p, 52, 11)/*exponent*/ == 0x7ff
+	   || (bit_extract_simple(p, 52, 11)/*exponent*/ == 0
+	       && (bit_extract_simple(p, 0, 32)/*low mantisa*/ != 0
+		   || bit_extract_simple(p, 32, 20)/*high mantisa*/ != 0)));
   else
     val = 1;
   return (val);
